<?php
/**
 * Admin Withdrawal Approval Processing
 * LelangMobil Web App - Versi 2025
 * 
 * This script processes admin approval for withdrawal requests and automatically
 * deducts the appropriate amount from the user's balance.
 */

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Include database connection and functions
require_once '../config/database.php';
require_once '../config/functions.php';

// Check if admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // Redirect to login page if not logged in
    header("Location: login.php");
    exit;
}

// Set error reporting
error_reporting(E_ALL);
ini_set('display_errors', 0); // Set to 0 in production

// Process withdrawal approval
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    
    // Get transaction ID and action
    $transaction_id = isset($_POST['transaction_id']) ? intval($_POST['transaction_id']) : 0;
    $action = $_POST['action'];
    
    if (!$transaction_id) {
        $_SESSION['admin_error'] = "ID transaksi tidak valid.";
        header("Location: pending_withdrawals.php");
        exit;
    }
    
    // Begin transaction to ensure data consistency
    $conn->begin_transaction();
    
    try {
        // Get transaction details
        $transaction_sql = "SELECT t.*, u.balance FROM transactions t 
                           JOIN users u ON t.user_id = u.user_id 
                           WHERE t.transaction_id = ? AND t.type = 'withdrawal' AND t.status = 'pending'";
        $transaction_stmt = $conn->prepare($transaction_sql);
        $transaction_stmt->bind_param("i", $transaction_id);
        $transaction_stmt->execute();
        $transaction_result = $transaction_stmt->get_result();
        
        if ($transaction_result->num_rows === 0) {
            throw new Exception("Transaksi tidak ditemukan atau sudah diproses.");
        }
        
        $transaction = $transaction_result->fetch_assoc();
        $user_id = $transaction['user_id'];
        $amount = $transaction['amount'];
        $current_balance = $transaction['balance'];
        
        if ($action === 'approve') {
            // Check if user has sufficient balance
            if ($current_balance < $amount) {
                throw new Exception("Saldo pengguna tidak mencukupi untuk penarikan ini.");
            }
            
            // Update transaction status to completed
            $update_transaction_sql = "UPDATE transactions SET status = 'completed', processed_date = NOW(), 
                                      processed_by = ?, admin_notes = ? WHERE transaction_id = ?";
            $admin_notes = isset($_POST['admin_notes']) ? $_POST['admin_notes'] : "Disetujui oleh admin";
            $admin_id = $_SESSION['admin_id'];
            
            $update_transaction_stmt = $conn->prepare($update_transaction_sql);
            $update_transaction_stmt->bind_param("isi", $admin_id, $admin_notes, $transaction_id);
            $update_transaction_stmt->execute();
            
            // Deduct amount from user balance
            $update_balance_sql = "UPDATE users SET balance = balance - ? WHERE user_id = ?";
            $update_balance_stmt = $conn->prepare($update_balance_sql);
            $update_balance_stmt->bind_param("di", $amount, $user_id);
            $update_balance_stmt->execute();
            
            // Create a notification for the user
            $notification_sql = "INSERT INTO notifications (user_id, type, message, related_id, created_at) 
                                VALUES (?, 'withdrawal', ?, ?, NOW())";
            $notification_message = "Penarikan Anda sebesar Rp" . number_format($amount, 0, ',', '.') . " telah disetujui dan sedang diproses.";
            
            $notification_stmt = $conn->prepare($notification_sql);
            $notification_stmt->bind_param("isi", $user_id, $notification_message, $transaction_id);
            $notification_stmt->execute();
            
            $success_message = "Penarikan berhasil disetujui dan saldo pengguna telah dikurangi otomatis.";
        } 
        elseif ($action === 'reject') {
            // Update transaction status to rejected
            $update_transaction_sql = "UPDATE transactions SET status = 'rejected', processed_date = NOW(), 
                                      processed_by = ?, admin_notes = ? WHERE transaction_id = ?";
            $admin_notes = isset($_POST['admin_notes']) ? $_POST['admin_notes'] : "Ditolak oleh admin";
            $admin_id = $_SESSION['admin_id'];
            
            $update_transaction_stmt = $conn->prepare($update_transaction_sql);
            $update_transaction_stmt->bind_param("isi", $admin_id, $admin_notes, $transaction_id);
            $update_transaction_stmt->execute();
            
            // Create a notification for the user
            $notification_sql = "INSERT INTO notifications (user_id, type, message, related_id, created_at) 
                                VALUES (?, 'withdrawal', ?, ?, NOW())";
            $notification_message = "Penarikan Anda sebesar Rp" . number_format($amount, 0, ',', '.') . " ditolak. Alasan: " . $admin_notes;
            
            $notification_stmt = $conn->prepare($notification_sql);
            $notification_stmt->bind_param("isi", $user_id, $notification_message, $transaction_id);
            $notification_stmt->execute();
            
            $success_message = "Penarikan berhasil ditolak.";
        } 
        else {
            throw new Exception("Tindakan tidak valid.");
        }
        
        // Commit transaction
        $conn->commit();
        
        // Set success message
        $_SESSION['admin_success'] = $success_message;
        
    } catch (Exception $e) {
        // Rollback transaction on error
        $conn->rollback();
        
        // Set error message
        $_SESSION['admin_error'] = "Error: " . $e->getMessage();
    }
    
    // Redirect back to pending withdrawals page
    header("Location: pending_withdrawals.php");
    exit;
}

// If accessed directly without POST data, redirect to dashboard
header("Location: dashboard.php");
exit;
?>
