<?php
// Set page title
$page_title = "Manajemen Transaksi";

// Include header
include 'includes/header.php';

// Process transaction approval/rejection
if (isset($_GET['action']) && isset($_GET['id'])) {
    $action = $_GET['action'];
    $transaction_id = intval($_GET['id']);
    
    // Validate transaction exists
    $check_sql = "SELECT t.*, u.username, u.balance 
                 FROM transactions t 
                 JOIN users u ON t.user_id = u.user_id 
                 WHERE t.transaction_id = ?";
    $check_stmt = $conn->prepare($check_sql);
    $check_stmt->bind_param("i", $transaction_id);
    $check_stmt->execute();
    $check_result = $check_stmt->get_result();
    
    if ($check_result->num_rows > 0) {
        $transaction = $check_result->fetch_assoc();
        
        // Check if transaction is still pending
        if ($transaction['status'] == 'pending') {
            $conn->begin_transaction();
            
            try {
                if ($action == 'approve') {
                    // Update transaction status
                    $update_sql = "UPDATE transactions SET status = 'completed', admin_id = ?, updated_at = NOW() WHERE transaction_id = ?";
                    $update_stmt = $conn->prepare($update_sql);
                    $update_stmt->bind_param("ii", $admin_id, $transaction_id);
                    $update_stmt->execute();
                    
                    // Update user balance berdasarkan tipe transaksi
                    if ($transaction['type'] == 'deposit') {
                        // Untuk deposit, tambahkan ke saldo pengguna
                        $new_balance = $transaction['balance'] + $transaction['amount'];
                        $balance_sql = "UPDATE users SET balance = ? WHERE user_id = ?";
                        $balance_stmt = $conn->prepare($balance_sql);
                        $balance_stmt->bind_param("di", $new_balance, $transaction['user_id']);
                        $balance_stmt->execute();
                        $notification_title = "Top-up Disetujui";
                    } elseif ($transaction['type'] == 'withdrawal') {
                        // Untuk penarikan, kurangi saldo pengguna
                        if ($transaction['balance'] >= $transaction['amount']) {
                            $new_balance = $transaction['balance'] - $transaction['amount'];
                            $balance_sql = "UPDATE users SET balance = ? WHERE user_id = ?";
                            $balance_stmt = $conn->prepare($balance_sql);
                            $balance_stmt->bind_param("di", $new_balance, $transaction['user_id']);
                            $balance_stmt->execute();
                            $notification_title = "Penarikan Disetujui";
                        } else {
                            // Jika saldo tidak cukup, batalkan persetujuan
                            throw new Exception("Saldo pengguna tidak mencukupi untuk penarikan ini");
                        }
                    }
                    
                    // Log transaction approval
                    $log_sql = "INSERT INTO transaction_logs (transaction_id, admin_id, action, notes, created_at) 
                               VALUES (?, ?, 'approved', 'Transaksi disetujui', NOW())";
                    $log_stmt = $conn->prepare($log_sql);
                    $log_stmt->bind_param("ii", $transaction_id, $admin_id);
                    $log_stmt->execute();
                    
                    $conn->commit();
                    $success = "Transaksi berhasil disetujui dan saldo pengguna telah diperbarui.";
                    
                    // Send notification to user
                    $notification_message = "Top-up sebesar " . format_money($transaction['amount']) . " telah disetujui dan saldo Anda telah diperbarui.";
                    
                    if (function_exists('send_notification')) {
                        send_notification($transaction['user_id'], 'transaction', $notification_title, $notification_message);
                    }
                } 
                elseif ($action == 'reject') {
                    // Update transaction status
                    $update_sql = "UPDATE transactions SET status = 'rejected', admin_id = ?, updated_at = NOW() WHERE transaction_id = ?";
                    $update_stmt = $conn->prepare($update_sql);
                    $update_stmt->bind_param("ii", $admin_id, $transaction_id);
                    $update_stmt->execute();
                    
                    $conn->commit();
                    $success = "Transaksi berhasil ditolak.";
                    
                    // Send notification to user
                    $notification_title = "Top-up Ditolak";
                    $notification_message = "Top-up sebesar " . format_money($transaction['amount']) . " telah ditolak. Silakan hubungi admin untuk informasi lebih lanjut.";
                    
                    if (function_exists('send_notification')) {
                        send_notification($transaction['user_id'], 'transaction', $notification_title, $notification_message);
                    }
                }
            } catch (Exception $e) {
                $conn->rollback();
                $error = "Terjadi kesalahan: " . $e->getMessage();
            }
        } else {
            $error = "Transaksi ini sudah diproses sebelumnya.";
        }
    } else {
        $error = "Transaksi tidak ditemukan.";
    }
}

// Pagination
$items_per_page = 15;
$current_page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$offset = ($current_page - 1) * $items_per_page;

// Filtering
$where_clause = "1=1"; // Default to show all transactions
$params = [];
$param_types = "";

// Search by transaction ID or username
if (isset($_GET['search']) && !empty($_GET['search'])) {
    $search = clean_input($_GET['search']);
    if (is_numeric($search)) {
        // Search by transaction ID
        $where_clause .= " AND t.transaction_id = ?";
        $params[] = intval($search);
        $param_types .= "i";
    } else {
        // Search by username
        $search = "%$search%";
        $where_clause .= " AND u.username LIKE ?";
        $params[] = $search;
        $param_types .= "s";
    }
}

// Filter by transaction type
if (isset($_GET['type']) && !empty($_GET['type'])) {
    $type = clean_input($_GET['type']);
    $where_clause .= " AND t.type = ?";
    $params[] = $type;
    $param_types .= "s";
}

// Filter by transaction status
if (isset($_GET['status']) && !empty($_GET['status'])) {
    $status = clean_input($_GET['status']);
    $where_clause .= " AND t.status = ?";
    $params[] = $status;
    $param_types .= "s";
}

// Handle period filter
if (isset($_GET['period']) && !empty($_GET['period'])) {
    $period = clean_input($_GET['period']);
    
    switch ($period) {
        case 'today':
            $where_clause .= " AND DATE(t.created_at) = CURDATE()";
            break;
        case 'week':
            $where_clause .= " AND YEARWEEK(t.created_at, 1) = YEARWEEK(CURDATE(), 1)";
            break;
        case 'month':
            $where_clause .= " AND YEAR(t.created_at) = YEAR(CURDATE()) AND MONTH(t.created_at) = MONTH(CURDATE())";
            break;
    }
}

// Count total transactions matching criteria
$count_sql = "SELECT COUNT(*) as total 
             FROM transactions t 
             JOIN users u ON t.user_id = u.user_id 
             WHERE $where_clause";
$count_stmt = $conn->prepare($count_sql);
if (!empty($params)) {
    $count_stmt->bind_param($param_types, ...$params);
}
$count_stmt->execute();
$count_result = $count_stmt->get_result();
$count_row = $count_result->fetch_assoc();
$total_items = $count_row['total'];
$total_pages = ceil($total_items / $items_per_page);

// Get transactions with pagination
$transactions_sql = "SELECT t.*, u.username, a.username as admin_username
                    FROM transactions t 
                    JOIN users u ON t.user_id = u.user_id 
                    LEFT JOIN users a ON t.admin_id = a.user_id 
                    WHERE $where_clause 
                    ORDER BY t.created_at DESC 
                    LIMIT ?, ?";
$params[] = $offset;
$params[] = $items_per_page;
$param_types .= "ii";

$transactions_stmt = $conn->prepare($transactions_sql);
$transactions_stmt->bind_param($param_types, ...$params);
$transactions_stmt->execute();
$transactions_result = $transactions_stmt->get_result();
?>

<div class="admin-page-header">
    <h1>Manajemen Transaksi</h1>
    <div class="admin-page-actions">
        <a href="transactions.php?status=pending&type=deposit" class="admin-btn admin-btn-primary">
            <i class="fa fa-filter"></i> Lihat Top-up Pending
        </a>
    </div>
</div>

<?php if(isset($success)): ?>
    <div class="admin-alert admin-alert-success"><?php echo $success; ?></div>
<?php endif; ?>

<?php if(isset($error)): ?>
    <div class="admin-alert admin-alert-danger"><?php echo $error; ?></div>
<?php endif; ?>

<?php
// Get transaction statistics
$stats_sql = "SELECT 
    COUNT(*) as total_count,
    SUM(CASE WHEN status = 'pending' THEN 1 ELSE 0 END) as pending_count,
    SUM(CASE WHEN status = 'completed' THEN 1 ELSE 0 END) as completed_count,
    SUM(CASE WHEN status = 'rejected' THEN 1 ELSE 0 END) as rejected_count,
    SUM(CASE WHEN status = 'completed' AND type = 'deposit' THEN amount ELSE 0 END) as total_topup
    FROM transactions
    WHERE type IN ('deposit', 'withdrawal')"
;
$stats_result = $conn->query($stats_sql);
$stats = $stats_result->fetch_assoc();
?>

<!-- Transaction Statistics -->
<div class="admin-stats">
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-exchange-alt"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['total_count']); ?></h3>
            <p>Total Transaksi</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-clock"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['pending_count']); ?></h3>
            <p>Menunggu Persetujuan</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-check-circle"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['completed_count']); ?></h3>
            <p>Selesai</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-times-circle"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['rejected_count']); ?></h3>
            <p>Ditolak</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-wallet"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo format_money($stats['total_topup']); ?></h3>
            <p>Total Top-up</p>
        </div>
    </div>
</div>

<!-- Filter Form -->
<div class="admin-card mb-4">
    <div class="admin-card-body">
        <form action="" method="get" class="admin-filter-form">
            <div class="admin-filter-row">
                <div class="admin-filter-group">
                    <label>Cari</label>
                    <input type="text" name="search" class="admin-form-control" placeholder="ID transaksi atau username..." value="<?php echo isset($_GET['search']) ? htmlspecialchars($_GET['search']) : ''; ?>">
                </div>
                
                <div class="admin-filter-group">
                    <label>Tipe</label>
                    <select name="type" class="admin-form-select">
                        <option value="">Semua Tipe</option>
                        <option value="deposit" <?php echo (isset($_GET['type']) && $_GET['type'] == 'deposit') ? 'selected' : ''; ?>>Top-up</option>
                        <option value="withdrawal" <?php echo (isset($_GET['type']) && $_GET['type'] == 'withdrawal') ? 'selected' : ''; ?>>Penarikan</option>
                        <option value="bid_hold" <?php echo (isset($_GET['type']) && $_GET['type'] == 'bid_hold') ? 'selected' : ''; ?>>Hold Bid</option>
                        <option value="bid_release" <?php echo (isset($_GET['type']) && $_GET['type'] == 'bid_release') ? 'selected' : ''; ?>>Release Bid</option>
                        <option value="winning_payment" <?php echo (isset($_GET['type']) && $_GET['type'] == 'winning_payment') ? 'selected' : ''; ?>>Pembayaran Menang</option>
                    </select>
                </div>
                
                <div class="admin-filter-group">
                    <label>Status</label>
                    <select name="status" class="admin-form-select">
                        <option value="">Semua Status</option>
                        <option value="pending" <?php echo (isset($_GET['status']) && $_GET['status'] == 'pending') ? 'selected' : ''; ?>>Pending</option>
                        <option value="completed" <?php echo (isset($_GET['status']) && $_GET['status'] == 'completed') ? 'selected' : ''; ?>>Selesai</option>
                        <option value="rejected" <?php echo (isset($_GET['status']) && $_GET['status'] == 'rejected') ? 'selected' : ''; ?>>Ditolak</option>
                    </select>
                </div>
                
                <div class="admin-filter-group">
                    <label>Periode</label>
                    <select name="period" class="admin-form-select">
                        <option value="">Semua Waktu</option>
                        <option value="today" <?php echo (isset($_GET['period']) && $_GET['period'] == 'today') ? 'selected' : ''; ?>>Hari Ini</option>
                        <option value="week" <?php echo (isset($_GET['period']) && $_GET['period'] == 'week') ? 'selected' : ''; ?>>Minggu Ini</option>
                        <option value="month" <?php echo (isset($_GET['period']) && $_GET['period'] == 'month') ? 'selected' : ''; ?>>Bulan Ini</option>
                    </select>
                </div>
                
                <div class="admin-filter-actions">
                    <button type="submit" class="admin-btn admin-btn-primary">
                        <i class="fa fa-filter"></i> Filter
                    </button>
                    <a href="transactions.php" class="admin-btn admin-btn-outline">
                        <i class="fa fa-sync"></i> Reset
                    </a>
                </div>
            </div>
        </form>
    </div>
</div>

<!-- Transactions Table -->
<div class="admin-card">
    <div class="admin-card-body">
        <div class="table-responsive">
            <table class="admin-table">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Pengguna</th>
                        <th>Tanggal</th>
                        <th>Jumlah</th>
                        <th>Tipe</th>
                        <th>Status</th>
                        <th>Bukti</th>
                        <th>Diproses Oleh</th>
                        <th>Aksi</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($transactions_result->num_rows > 0): ?>
                        <?php while ($transaction = $transactions_result->fetch_assoc()): ?>
                            <tr>
                                <td><?php echo $transaction['transaction_id']; ?></td>
                                <td>
                                    <a href="user-detail.php?id=<?php echo $transaction['user_id']; ?>" class="admin-link">
                                        <?php echo $transaction['username']; ?>
                                    </a>
                                </td>
                                <td><?php echo date('d M Y H:i', strtotime($transaction['created_at'])); ?></td>
                                <td><?php echo format_money($transaction['amount']); ?></td>
                                <td>
                                    <?php
                                    switch ($transaction['type']) {
                                        case 'deposit':
                                            echo '<span class="admin-badge admin-badge-success">Top-up</span>';
                                            break;
                                        case 'withdrawal':
                                            echo '<span class="admin-badge admin-badge-warning">Penarikan</span>';
                                            break;
                                        case 'bid_hold':
                                            echo '<span class="admin-badge admin-badge-info">Hold Bid</span>';
                                            break;
                                        case 'bid_release':
                                            echo '<span class="admin-badge admin-badge-secondary">Release Bid</span>';
                                            break;
                                        case 'winning_payment':
                                            echo '<span class="admin-badge admin-badge-primary">Pembayaran Menang</span>';
                                            break;
                                        default:
                                            echo $transaction['type'];
                                    }
                                    ?>
                                </td>
                                <td>
                                    <?php
                                    if ($transaction['status'] == 'pending') {
                                        echo '<span class="admin-badge admin-badge-warning">Menunggu</span>';
                                    } elseif ($transaction['status'] == 'completed') {
                                        echo '<span class="admin-badge admin-badge-success">Selesai</span>';
                                    } elseif ($transaction['status'] == 'rejected') {
                                        echo '<span class="admin-badge admin-badge-danger">Ditolak</span>';
                                    } else {
                                        echo $transaction['status'];
                                    }
                                    ?>
                                </td>
                                <td>
                                    <?php if (!empty($transaction['payment_proof'])): ?>
                                        <a href="../<?php echo $transaction['payment_proof']; ?>" target="_blank" class="admin-btn admin-btn-sm admin-btn-info">
                                            <i class="fa fa-image"></i>
                                        </a>
                                    <?php else: ?>
                                        -
                                    <?php endif; ?>
                                </td>
                                <td><?php echo $transaction['admin_username'] ? $transaction['admin_username'] : '-'; ?></td>
                                <td>
                                    <?php if ($transaction['status'] == 'pending' && $transaction['type'] == 'deposit'): ?>
                                        <div class="admin-btn-group">
                                            <a href="transactions.php?action=approve&id=<?php echo $transaction['transaction_id']; ?>" class="admin-btn admin-btn-sm admin-btn-success" onclick="return confirm('Yakin ingin menyetujui transaksi ini?')">
                                                <i class="fa fa-check"></i> Setujui
                                            </a>
                                            <a href="transactions.php?action=reject&id=<?php echo $transaction['transaction_id']; ?>" class="admin-btn admin-btn-sm admin-btn-danger" onclick="return confirm('Yakin ingin menolak transaksi ini?')">
                                                <i class="fa fa-times"></i> Tolak
                                            </a>
                                        </div>
                                    <?php else: ?>
                                        <a href="transaction-detail.php?id=<?php echo $transaction['transaction_id']; ?>" class="admin-btn admin-btn-sm admin-btn-primary">
                                            <i class="fa fa-eye"></i> Detail
                                        </a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="9" class="text-center">Tidak ada transaksi yang ditemukan</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
        
        <!-- Pagination -->
        <?php if ($total_pages > 1): ?>
            <div class="admin-pagination">
                <?php if ($current_page > 1): ?>
                    <a href="<?php echo "transactions.php?" . http_build_query(array_merge($_GET, ['page' => $current_page - 1])); ?>" class="admin-pagination-item">
                        <i class="fa fa-chevron-left"></i>
                    </a>
                <?php endif; ?>
                
                <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                    <a href="<?php echo "transactions.php?" . http_build_query(array_merge($_GET, ['page' => $i])); ?>" class="admin-pagination-item <?php echo ($i == $current_page) ? 'active' : ''; ?>">
                        <?php echo $i; ?>
                    </a>
                <?php endfor; ?>
                
                <?php if ($current_page < $total_pages): ?>
                    <a href="<?php echo "transactions.php?" . http_build_query(array_merge($_GET, ['page' => $current_page + 1])); ?>" class="admin-pagination-item">
                        <i class="fa fa-chevron-right"></i>
                    </a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</div>

<style>
.admin-page-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-bottom: 20px;
}

.admin-page-actions {
    display: flex;
    gap: 10px;
}

.admin-filter-form {
    display: flex;
    flex-direction: column;
    gap: 15px;
}

.admin-filter-row {
    display: flex;
    flex-wrap: wrap;
    gap: 15px;
    align-items: flex-end;
}

.admin-filter-group {
    flex: 1;
    min-width: 200px;
}

.admin-filter-group label {
    display: block;
    margin-bottom: 5px;
    font-weight: 500;
}

.admin-filter-actions {
    display: flex;
    gap: 10px;
    align-items: flex-end;
}

.admin-badge {
    padding: 5px 10px;
    border-radius: 4px;
    font-size: 12px;
    font-weight: 600;
    text-transform: uppercase;
    display: inline-block;
}

.admin-badge-success {
    background-color: rgba(40, 167, 69, 0.1);
    color: #28a745;
}

.admin-badge-warning {
    background-color: rgba(255, 193, 7, 0.1);
    color: #ffc107;
}

.admin-badge-danger {
    background-color: rgba(220, 53, 69, 0.1);
    color: #dc3545;
}

.admin-badge-info {
    background-color: rgba(23, 162, 184, 0.1);
    color: #17a2b8;
}

.admin-badge-secondary {
    background-color: rgba(108, 117, 125, 0.1);
    color: #6c757d;
}

.admin-badge-primary {
    background-color: rgba(0, 123, 255, 0.1);
    color: #007bff;
}

.admin-btn-group {
    display: flex;
    gap: 5px;
}

.admin-link {
    color: var(--primary);
    text-decoration: none;
    font-weight: 500;
}

.admin-link:hover {
    text-decoration: underline;
}
</style>

<?php
// Include footer
include 'includes/footer.php';
?>