<?php
/**
 * Notifications API
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once '../config/init.php';

// Check if user is logged in
if (!is_logged_in()) {
    echo json_encode([
        'success' => false,
        'message' => 'Unauthorized'
    ]);
    exit;
}

$user_id = $_SESSION['user_id'];
$action = $_GET['action'] ?? '';

// Handle different actions
switch ($action) {
    case 'get':
        // Get notifications
        getNotifications($user_id);
        break;
        
    case 'count':
        // Count unread notifications
        countUnreadNotifications($user_id);
        break;
        
    case 'mark_read':
        // Mark notification as read
        markNotificationRead($user_id);
        break;
        
    case 'mark_all_read':
        // Mark all notifications as read
        markAllNotificationsRead($user_id);
        break;
        
    case 'check':
        // Check for new notifications
        checkNewNotifications($user_id);
        break;
        
    default:
        echo json_encode([
            'success' => false,
            'message' => 'Invalid action'
        ]);
        break;
}

/**
 * Get notifications for user
 */
function getNotifications($user_id) {
    global $conn;
    
    try {
        $limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 10;
        $offset = isset($_GET['offset']) ? (int)$_GET['offset'] : 0;
        
        $sql = "SELECT * FROM notifications 
                WHERE user_id = ? 
                ORDER BY created_at DESC 
                LIMIT ? OFFSET ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("iii", $user_id, $limit, $offset);
        $stmt->execute();
        $result = $stmt->get_result();
        
        $notifications = [];
        while ($row = $result->fetch_assoc()) {
            $notifications[] = $row;
        }
        
        echo json_encode([
            'success' => true,
            'notifications' => $notifications,
            'total' => countTotalNotifications($user_id),
            'unread' => countUnreadNotificationsTotal($user_id)
        ]);
    } catch (Exception $e) {
        echo json_encode([
            'success' => false,
            'message' => 'Error: ' . $e->getMessage()
        ]);
    }
}

/**
 * Count unread notifications
 */
function countUnreadNotifications($user_id) {
    global $conn;
    
    try {
        $count = countUnreadNotificationsTotal($user_id);
        
        echo json_encode([
            'success' => true,
            'count' => $count
        ]);
    } catch (Exception $e) {
        echo json_encode([
            'success' => false,
            'message' => 'Error: ' . $e->getMessage()
        ]);
    }
}

/**
 * Mark notification as read
 */
function markNotificationRead($user_id) {
    global $conn;
    
    try {
        $notification_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
        
        if ($notification_id <= 0) {
            echo json_encode([
                'success' => false,
                'message' => 'Invalid notification ID'
            ]);
            return;
        }
        
        $sql = "UPDATE notifications 
                SET is_read = 1 
                WHERE notification_id = ? AND user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $notification_id, $user_id);
        $stmt->execute();
        
        if ($stmt->affected_rows > 0) {
            $unread_count = countUnreadNotificationsTotal($user_id);
            
            echo json_encode([
                'success' => true,
                'message' => 'Notification marked as read',
                'unread_count' => $unread_count
            ]);
        } else {
            echo json_encode([
                'success' => false,
                'message' => 'Failed to mark notification as read'
            ]);
        }
    } catch (Exception $e) {
        echo json_encode([
            'success' => false,
            'message' => 'Error: ' . $e->getMessage()
        ]);
    }
}

/**
 * Mark all notifications as read
 */
function markAllNotificationsRead($user_id) {
    global $conn;
    
    try {
        $sql = "UPDATE notifications 
                SET is_read = 1 
                WHERE user_id = ? AND is_read = 0";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        
        echo json_encode([
            'success' => true,
            'message' => 'All notifications marked as read',
            'affected_rows' => $stmt->affected_rows
        ]);
    } catch (Exception $e) {
        echo json_encode([
            'success' => false,
            'message' => 'Error: ' . $e->getMessage()
        ]);
    }
}

/**
 * Check for new notifications
 */
function checkNewNotifications($user_id) {
    global $conn;
    
    try {
        $last_check = isset($_GET['last_check']) ? $_GET['last_check'] : null;
        
        if ($last_check) {
            $sql = "SELECT * FROM notifications 
                    WHERE user_id = ? AND created_at > ? 
                    ORDER BY created_at DESC";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("is", $user_id, $last_check);
        } else {
            $sql = "SELECT * FROM notifications 
                    WHERE user_id = ? AND is_read = 0 
                    ORDER BY created_at DESC 
                    LIMIT 5";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $user_id);
        }
        
        $stmt->execute();
        $result = $stmt->get_result();
        
        $notifications = [];
        while ($row = $result->fetch_assoc()) {
            $notifications[] = $row;
        }
        
        echo json_encode([
            'success' => true,
            'notifications' => $notifications,
            'count' => count($notifications),
            'unread_total' => countUnreadNotificationsTotal($user_id)
        ]);
    } catch (Exception $e) {
        echo json_encode([
            'success' => false,
            'message' => 'Error: ' . $e->getMessage()
        ]);
    }
}

/**
 * Count total notifications
 */
function countTotalNotifications($user_id) {
    global $conn;
    
    $sql = "SELECT COUNT(*) as count FROM notifications WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();
    
    return $row['count'];
}

/**
 * Count unread notifications total
 */
function countUnreadNotificationsTotal($user_id) {
    global $conn;
    
    $sql = "SELECT COUNT(*) as count FROM notifications WHERE user_id = ? AND is_read = 0";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();
    
    return $row['count'];
}
?>