<?php
/**
 * Helper Functions
 * LelangMobil Web App - Versi 2025
 */

// Fungsi untuk mendapatkan base URL
if (!function_exists('get_base_url')) {
    function get_base_url() {
        $protocol = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? 'https://' : 'http://';
        $host = $_SERVER['HTTP_HOST'] ?? 'localhost';
        $path = dirname($_SERVER['PHP_SELF'] ?? '');
        $path = str_replace('\\\\', '/', $path);
        $path = $path !== '/' ? rtrim($path, '/') : '';
        
        return $protocol . $host . $path;
    }
}

// Fungsi untuk sanitasi input
if (!function_exists('clean_input')) {
    function clean_input($data) {
        $data = trim($data);
        $data = stripslashes($data);
        $data = htmlspecialchars($data);
        return $data;
    }
}

// Fungsi untuk sanitasi input
if (!function_exists('sanitize_input')) {
    function sanitize_input($input) {
        if (is_array($input)) {
            foreach ($input as $key => $value) {
                $input[$key] = sanitize_input($value);
            }
        } else {
            $input = trim($input);
            $input = stripslashes($input);
            $input = htmlspecialchars($input, ENT_QUOTES, 'UTF-8');
        }
        return $input;
    }
}

// Fungsi untuk validasi email
if (!function_exists('is_valid_email')) {
    function is_valid_email($email) {
        return filter_var($email, FILTER_VALIDATE_EMAIL);
    }
}

// Fungsi untuk validasi password
if (!function_exists('is_valid_password')) {
    function is_valid_password($password) {
        // Minimal 8 karakter
        return strlen($password) >= 8;
    }
}

// Fungsi untuk validasi username
if (!function_exists('is_valid_username')) {
    function is_valid_username($username) {
        // Hanya huruf, angka, dan underscore, minimal 3 karakter
        return preg_match('/^[a-zA-Z0-9_]{3,}$/', $username);
    }
}

// Fungsi untuk validasi nomor telepon
if (!function_exists('is_valid_phone')) {
    function is_valid_phone($phone) {
        // Hanya angka, +, dan -, minimal 8 karakter
        return preg_match('/^[0-9+\-]{8,}$/', $phone);
    }
}

// Fungsi untuk validasi jumlah uang
if (!function_exists('is_valid_amount')) {
    function is_valid_amount($amount) {
        // Hanya angka dan titik, minimal 1
        return is_numeric($amount) && $amount > 0;
    }
}

// Fungsi untuk format uang
if (!function_exists('format_money')) {
    function format_money($amount) {
        return 'Rp' . number_format($amount, 0, ',', '.');
    }
}

// Fungsi untuk format tanggal
if (!function_exists('format_date')) {
    function format_date($date) {
        return date('d M Y', strtotime($date));
    }
}

// Fungsi untuk format tanggal dan waktu
if (!function_exists('format_datetime')) {
    function format_datetime($datetime) {
        return date('d M Y H:i', strtotime($datetime));
    }
}

// Fungsi untuk mendapatkan sisa waktu
if (!function_exists('get_remaining_time')) {
    function get_remaining_time($end_date) {
        $now = new DateTime();
        $end = new DateTime($end_date);
        $interval = $now->diff($end);
        
        if ($interval->days > 0) {
            return $interval->days . " hari " . $interval->h . " jam";
        } elseif ($interval->h > 0) {
            return $interval->h . " jam " . $interval->i . " menit";
        } else {
            return $interval->i . " menit";
        }
    }
}

// Fungsi untuk cek apakah user sudah login
if (!function_exists('is_logged_in')) {
    function is_logged_in() {
        return isset($_SESSION['user_id']);
    }
}

// Fungsi untuk cek apakah user adalah admin
if (!function_exists('is_admin')) {
    function is_admin() {
        return isset($_SESSION['is_admin']) && $_SESSION['is_admin'] == 1;
    }
}

// Fungsi untuk redirect ke halaman login jika user belum login
if (!function_exists('require_login')) {
    function require_login($redirect_url = '') {
        if (!is_logged_in()) {
            $redirect = empty($redirect_url) ? '' : '?redirect=' . urlencode($redirect_url);
            header("Location: login.php$redirect");
            exit;
        }
    }
}

// Fungsi untuk redirect ke halaman error jika user bukan admin
if (!function_exists('require_admin')) {
    function require_admin() {
        if (!is_admin()) {
            header("Location: error.php?code=403");
            exit;
        }
    }
}

// Fungsi untuk set flash message
if (!function_exists('set_flash_message')) {
    function set_flash_message($type, $message) {
        $_SESSION['flash_message'] = [
            'type' => $type,
            'message' => $message,
            'time' => time()
        ];
    }
}

// Fungsi untuk get flash message
if (!function_exists('get_flash_message')) {
    function get_flash_message() {
        if (isset($_SESSION['flash_message'])) {
            $message = $_SESSION['flash_message'];
            unset($_SESSION['flash_message']);
            
            // Hanya kembalikan pesan jika belum lebih dari 5 menit
            if (time() - $message['time'] < 300) {
                return $message;
            }
        }
        return null;
    }
}

// Fungsi untuk menghasilkan token acak
if (!function_exists('generate_token')) {
    function generate_token($length = 32) {
        return bin2hex(random_bytes($length / 2));
    }
}

// Fungsi untuk mendapatkan status transaksi dalam bahasa Indonesia
if (!function_exists('get_transaction_status')) {
    function get_transaction_status($status) {
        $statuses = [
            'pending' => 'Menunggu',
            'verification' => 'Verifikasi',
            'completed' => 'Selesai',
            'rejected' => 'Ditolak',
            'cancelled' => 'Dibatalkan'
        ];
        
        return $statuses[$status] ?? $status;
    }
}

// Fungsi untuk mendapatkan jenis transaksi dalam bahasa Indonesia
if (!function_exists('get_transaction_type')) {
    function get_transaction_type($type) {
        $types = [
            'deposit' => 'Top Up',
            'withdrawal' => 'Penarikan',
            'bid_hold' => 'Hold Bid',
            'bid_release' => 'Release Bid',
            'bid_win' => 'Menang Lelang',
            'winning_payment' => 'Pembayaran Menang'
        ];
        
        return $types[$type] ?? $type;
    }
}

// Fungsi untuk mendapatkan status kendaraan dalam bahasa Indonesia
if (!function_exists('get_vehicle_status')) {
    function get_vehicle_status($status) {
        $statuses = [
            'upcoming' => 'Akan Datang',
            'active' => 'Aktif',
            'ended' => 'Berakhir',
            'sold' => 'Terjual',
            'not_sold' => 'Tidak Terjual'
        ];
        
        return $statuses[$status] ?? $status;
    }
}

// Fungsi untuk mendapatkan URL gambar kendaraan
if (!function_exists('get_vehicle_image')) {
    function get_vehicle_image($image, $default = 'images/no-image.svg') {
        if (empty($image)) {
            return $default;
        }
        
        if (file_exists($image)) {
            return $image;
        }
        
        return $default;
    }
}

// Fungsi untuk membuat slug
if (!function_exists('create_slug')) {
    function create_slug($string) {
        $string = strtolower($string);
        $string = preg_replace('/[^a-z0-9\-]/', '-', $string);
        $string = preg_replace('/-+/', '-', $string);
        $string = trim($string, '-');
        return $string;
    }
}

// Fungsi untuk memotong teks
if (!function_exists('truncate_text')) {
    function truncate_text($text, $length = 100, $append = '...') {
        if (strlen($text) <= $length) {
            return $text;
        }
        
        $text = substr($text, 0, $length);
        $text = substr($text, 0, strrpos($text, ' '));
        return $text . $append;
    }
}

// Fungsi untuk mendapatkan ekstensi file
if (!function_exists('get_file_extension')) {
    function get_file_extension($filename) {
        return pathinfo($filename, PATHINFO_EXTENSION);
    }
}

// Fungsi untuk menghasilkan nama file unik
if (!function_exists('generate_unique_filename')) {
    function generate_unique_filename($filename) {
        $extension = get_file_extension($filename);
        return uniqid() . '.' . $extension;
    }
}

// Fungsi untuk mengecek apakah file adalah gambar
if (!function_exists('is_image_file')) {
    function is_image_file($file) {
        $allowed_types = ['image/jpeg', 'image/png', 'image/gif', 'image/webp'];
        return in_array($file['type'], $allowed_types);
    }
}

// Fungsi untuk mengecek ukuran file
if (!function_exists('check_file_size')) {
    function check_file_size($file, $max_size = 2097152) { // 2MB default
        return $file['size'] <= $max_size;
    }
}

// Fungsi untuk upload file
if (!function_exists('upload_file')) {
    function upload_file($file, $destination, $allowed_types = [], $max_size = 2097152) {
        // Cek apakah ada error
        if ($file['error'] !== UPLOAD_ERR_OK) {
            return [
                'success' => false,
                'message' => 'Upload error: ' . $file['error']
            ];
        }
        
        // Cek tipe file jika ditentukan
        if (!empty($allowed_types) && !in_array($file['type'], $allowed_types)) {
            return [
                'success' => false,
                'message' => 'Tipe file tidak diizinkan'
            ];
        }
        
        // Cek ukuran file
        if ($file['size'] > $max_size) {
            return [
                'success' => false,
                'message' => 'Ukuran file terlalu besar (maksimal ' . ($max_size / 1048576) . 'MB)'
            ];
        }
        
        // Buat nama file unik
        $filename = generate_unique_filename($file['name']);
        $filepath = $destination . '/' . $filename;
        
        // Upload file
        if (move_uploaded_file($file['tmp_name'], $filepath)) {
            return [
                'success' => true,
                'filename' => $filename,
                'filepath' => $filepath
            ];
        } else {
            return [
                'success' => false,
                'message' => 'Gagal mengupload file'
            ];
        }
    }
}

// Fungsi untuk mengirim notifikasi
if (!function_exists('send_notification')) {
    function send_notification($user_id, $type, $title, $message, $data = []) {
        global $conn;
        
        // Insert ke database
        $sql = "INSERT INTO notifications (user_id, type, title, message, is_read, created_at) 
                VALUES (?, ?, ?, ?, 0, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("isss", $user_id, $type, $title, $message);
        
        return $stmt->execute();
    }
}

// Fungsi untuk mendapatkan notifikasi user
if (!function_exists('get_user_notifications')) {
    function get_user_notifications($user_id, $limit = 10, $offset = 0) {
        global $conn;
        
        $sql = "SELECT * FROM notifications 
                WHERE user_id = ? 
                ORDER BY created_at DESC 
                LIMIT ? OFFSET ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("iii", $user_id, $limit, $offset);
        $stmt->execute();
        
        return $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
    }
}

// Fungsi untuk menandai notifikasi sebagai dibaca
if (!function_exists('mark_notification_read')) {
    function mark_notification_read($notification_id, $user_id) {
        global $conn;
        
        $sql = "UPDATE notifications SET is_read = 1 
                WHERE notification_id = ? AND user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $notification_id, $user_id);
        
        return $stmt->execute();
    }
}

// Fungsi untuk menandai semua notifikasi user sebagai dibaca
if (!function_exists('mark_all_notifications_read')) {
    function mark_all_notifications_read($user_id) {
        global $conn;
        
        $sql = "UPDATE notifications SET is_read = 1 
                WHERE user_id = ? AND is_read = 0";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $user_id);
        
        return $stmt->execute();
    }
}

// Fungsi untuk menghitung notifikasi yang belum dibaca
if (!function_exists('count_unread_notifications')) {
    function count_unread_notifications($user_id) {
        global $conn;
        
        $sql = "SELECT COUNT(*) as count FROM notifications 
                WHERE user_id = ? AND is_read = 0";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        
        return $stmt->get_result()->fetch_assoc()['count'];
    }
}

// Fungsi untuk menambahkan item ke favorit
if (!function_exists('add_to_favorites')) {
    function add_to_favorites($user_id, $vehicle_id) {
        global $conn;
        
        $sql = "INSERT IGNORE INTO favorites (user_id, vehicle_id, created_at) 
                VALUES (?, ?, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $user_id, $vehicle_id);
        
        return $stmt->execute();
    }
}

// Fungsi untuk menghapus item dari favorit
if (!function_exists('remove_from_favorites')) {
    function remove_from_favorites($user_id, $vehicle_id) {
        global $conn;
        
        $sql = "DELETE FROM favorites 
                WHERE user_id = ? AND vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $user_id, $vehicle_id);
        
        return $stmt->execute();
    }
}

// Fungsi untuk mengecek apakah item ada di favorit
if (!function_exists('is_favorite')) {
    function is_favorite($user_id, $vehicle_id) {
        global $conn;
        
        $sql = "SELECT 1 FROM favorites 
                WHERE user_id = ? AND vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $user_id, $vehicle_id);
        $stmt->execute();
        
        return $stmt->get_result()->num_rows > 0;
    }
}

// Fungsi untuk mendapatkan daftar favorit user
if (!function_exists('get_user_favorites')) {
    function get_user_favorites($user_id, $limit = 10, $offset = 0) {
        global $conn;
        
        $sql = "SELECT v.*, f.created_at as favorited_at 
                FROM favorites f 
                JOIN vehicles v ON f.vehicle_id = v.vehicle_id 
                WHERE f.user_id = ? 
                ORDER BY f.created_at DESC 
                LIMIT ? OFFSET ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("iii", $user_id, $limit, $offset);
        $stmt->execute();
        
        return $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
    }
}

// Fungsi untuk menambahkan komentar
if (!function_exists('add_comment')) {
    function add_comment($user_id, $vehicle_id, $comment_text, $rating = null) {
        global $conn;
        
        $sql = "INSERT INTO comments (user_id, vehicle_id, comment_text, rating, created_at) 
                VALUES (?, ?, ?, ?, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("iisi", $user_id, $vehicle_id, $comment_text, $rating);
        
        return $stmt->execute();
    }
}

// Fungsi untuk mendapatkan komentar kendaraan
if (!function_exists('get_vehicle_comments')) {
    function get_vehicle_comments($vehicle_id, $limit = 10, $offset = 0) {
        global $conn;
        
        $sql = "SELECT c.*, u.username, u.full_name, u.profile_photo 
                FROM comments c 
                JOIN users u ON c.user_id = u.user_id 
                WHERE c.vehicle_id = ? 
                ORDER BY c.created_at DESC 
                LIMIT ? OFFSET ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("iii", $vehicle_id, $limit, $offset);
        $stmt->execute();
        
        return $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
    }
}

// Fungsi untuk mendapatkan rating kendaraan
if (!function_exists('get_vehicle_rating')) {
    function get_vehicle_rating($vehicle_id) {
        global $conn;
        
        $sql = "SELECT AVG(rating) as avg_rating, COUNT(*) as count 
                FROM comments 
                WHERE vehicle_id = ? AND rating IS NOT NULL";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicle_id);
        $stmt->execute();
        
        return $stmt->get_result()->fetch_assoc();
    }
}

// Fungsi untuk proses bid otomatis
if (!function_exists('process_auto_bid')) {
    function process_auto_bid($vehicle_id, $current_bid) {
        global $conn;
        
        // Dapatkan semua auto bid yang aktif untuk kendaraan ini
        $sql = "SELECT * FROM bids 
                WHERE vehicle_id = ? 
                AND is_auto_bid = 1 
                AND max_bid_amount > ? 
                ORDER BY max_bid_amount DESC, bid_time ASC";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("id", $vehicle_id, $current_bid);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $auto_bid = $result->fetch_assoc();
            $bidder_id = $auto_bid['bidder_id'];
            $increment = $auto_bid['bid_increment'] > 0 ? $auto_bid['bid_increment'] : 100000;
            $new_bid = $current_bid + $increment;
            
            // Pastikan tidak melebihi max bid
            if ($new_bid > $auto_bid['max_bid_amount']) {
                $new_bid = $auto_bid['max_bid_amount'];
            }
            
            // Insert bid baru
            $bid_sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, is_auto_bid, max_bid_amount, bid_increment, bid_time) 
                        VALUES (?, ?, ?, 1, ?, ?, NOW())";
            $bid_stmt = $conn->prepare($bid_sql);
            $bid_stmt->bind_param("iiddd", $vehicle_id, $bidder_id, $new_bid, $auto_bid['max_bid_amount'], $increment);
            $bid_stmt->execute();
            
            // Update current bid di kendaraan
            $update_sql = "UPDATE vehicles SET current_bid = ? WHERE vehicle_id = ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("di", $new_bid, $vehicle_id);
            $update_stmt->execute();
            
            // Kirim notifikasi
            $vehicle_sql = "SELECT CONCAT(brand, ' ', model) as vehicle_name FROM vehicles WHERE vehicle_id = ?";
            $vehicle_stmt = $conn->prepare($vehicle_sql);
            $vehicle_stmt->bind_param("i", $vehicle_id);
            $vehicle_stmt->execute();
            $vehicle_result = $vehicle_stmt->get_result();
            $vehicle = $vehicle_result->fetch_assoc();
            
            $title = "Auto Bid Berhasil";
            $message = "Auto bid Anda untuk " . $vehicle['vehicle_name'] . " berhasil dengan jumlah Rp" . number_format($new_bid, 0, ',', '.');
            send_notification($bidder_id, 'auto_bid', $title, $message);
            
            return $new_bid;
        }
        
        return $current_bid;
    }
}

// Fungsi untuk cek remember me cookie
if (!function_exists('check_remember_me')) {
    function check_remember_me($conn) {
        if (!is_logged_in() && isset($_COOKIE['remember_token']) && isset($_COOKIE['remember_user'])) {
            $token = $_COOKIE['remember_token'];
            $user_id = $_COOKIE['remember_user'];
            
            $sql = "SELECT * FROM users WHERE user_id = ? AND remember_token = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("is", $user_id, $token);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $user = $result->fetch_assoc();
                
                // Set session variables
                $_SESSION['user_id'] = $user['user_id'];
                $_SESSION['username'] = $user['username'];
                $_SESSION['is_admin'] = $user['is_admin'];
                
                // Update last login time
                $update_sql = "UPDATE users SET last_login = NOW() WHERE user_id = ?";
                $update_stmt = $conn->prepare($update_sql);
                $update_stmt->bind_param("i", $user['user_id']);
                $update_stmt->execute();
                
                return true;
            }
            
            // Token tidak valid, hapus cookie
            setcookie('remember_token', '', time() - 3600, '/');
            setcookie('remember_user', '', time() - 3600, '/');
        }
        
        return false;
    }
}

// Fungsi untuk mengambil data dari database dengan satu baris
if (!function_exists('db_get_row')) {
    function db_get_row($sql, $params = [], $types = '') {
        global $conn;
        
        $stmt = $conn->prepare($sql);
        
        if (!empty($params)) {
            if (empty($types)) {
                $types = str_repeat('s', count($params));
            }
            $stmt->bind_param($types, ...$params);
        }
        
        $stmt->execute();
        $result = $stmt->get_result();
        
        return $result->fetch_assoc();
    }
}

// Fungsi untuk mengambil data dari database dengan banyak baris
if (!function_exists('db_get_all')) {
    function db_get_all($sql, $params = [], $types = '') {
        global $conn;
        
        $stmt = $conn->prepare($sql);
        
        if (!empty($params)) {
            if (empty($types)) {
                $types = str_repeat('s', count($params));
            }
            $stmt->bind_param($types, ...$params);
        }
        
        $stmt->execute();
        $result = $stmt->get_result();
        
        return $result->fetch_all(MYSQLI_ASSOC);
    }
}

// Fungsi untuk mengoptimalkan gambar
if (!function_exists('get_optimized_image')) {
    function get_optimized_image($image_path, $width = null, $height = null) {
        // Jika tidak ada width atau height, kembalikan path asli
        if (empty($width) && empty($height)) {
            return $image_path;
        }
        
        // Jika file tidak ada, kembalikan path asli
        if (!file_exists($image_path)) {
            return $image_path;
        }
        
        return $image_path;
    }
}
?>