<?php
/**
 * Image Optimizer
 * LelangMobil Web App - Versi 2025
 */

class ImageOptimizer {
    private $quality;
    private $max_width;
    private $max_height;
    private $cache_dir;
    
    public function __construct($quality = 80, $max_width = 1200, $max_height = 1200, $cache_dir = null) {
        $this->quality = $quality;
        $this->max_width = $max_width;
        $this->max_height = $max_height;
        $this->cache_dir = $cache_dir ?? dirname(__DIR__) . '/cache/images';
        
        // Create cache directory if it doesn't exist
        if (!file_exists($this->cache_dir)) {
            mkdir($this->cache_dir, 0755, true);
        }
    }
    
    /**
     * Optimize image
     * 
     * @param string $source_path Source image path
     * @param string $destination_path Destination image path (optional)
     * @param int $quality Image quality (optional)
     * @param int $max_width Maximum width (optional)
     * @param int $max_height Maximum height (optional)
     * @return string|bool Destination path or false on failure
     */
    public function optimize($source_path, $destination_path = null, $quality = null, $max_width = null, $max_height = null) {
        // Check if source file exists
        if (!file_exists($source_path)) {
            return false;
        }
        
        // Set default values
        $quality = $quality ?? $this->quality;
        $max_width = $max_width ?? $this->max_width;
        $max_height = $max_height ?? $this->max_height;
        
        // Generate destination path if not provided
        if ($destination_path === null) {
            $pathinfo = pathinfo($source_path);
            $destination_path = $this->cache_dir . '/' . $pathinfo['filename'] . '_optimized.' . $pathinfo['extension'];
        }
        
        // Get image info
        $image_info = getimagesize($source_path);
        
        if ($image_info === false) {
            return false;
        }
        
        $mime_type = $image_info['mime'];
        $width = $image_info[0];
        $height = $image_info[1];
        
        // Check if image needs resizing
        $needs_resize = $width > $max_width || $height > $max_height;
        
        // Calculate new dimensions
        if ($needs_resize) {
            $ratio = $width / $height;
            
            if ($width > $height) {
                $new_width = $max_width;
                $new_height = $new_width / $ratio;
                
                if ($new_height > $max_height) {
                    $new_height = $max_height;
                    $new_width = $new_height * $ratio;
                }
            } else {
                $new_height = $max_height;
                $new_width = $new_height * $ratio;
                
                if ($new_width > $max_width) {
                    $new_width = $max_width;
                    $new_height = $new_width / $ratio;
                }
            }
        } else {
            $new_width = $width;
            $new_height = $height;
        }
        
        // Create image resource
        $source_image = $this->createImageFromFile($source_path, $mime_type);
        
        if ($source_image === false) {
            return false;
        }
        
        // Create destination image
        $destination_image = imagecreatetruecolor($new_width, $new_height);
        
        // Preserve transparency for PNG and GIF
        if ($mime_type === 'image/png' || $mime_type === 'image/gif') {
            imagealphablending($destination_image, false);
            imagesavealpha($destination_image, true);
            $transparent = imagecolorallocatealpha($destination_image, 255, 255, 255, 127);
            imagefilledrectangle($destination_image, 0, 0, $new_width, $new_height, $transparent);
        }
        
        // Resize image
        imagecopyresampled(
            $destination_image,
            $source_image,
            0, 0, 0, 0,
            $new_width, $new_height,
            $width, $height
        );
        
        // Save image
        $result = $this->saveImage($destination_image, $destination_path, $mime_type, $quality);
        
        // Free memory
        imagedestroy($source_image);
        imagedestroy($destination_image);
        
        return $result ? $destination_path : false;
    }
    
    /**
     * Create image resource from file
     * 
     * @param string $file_path File path
     * @param string $mime_type MIME type
     * @return resource|false Image resource or false on failure
     */
    private function createImageFromFile($file_path, $mime_type) {
        switch ($mime_type) {
            case 'image/jpeg':
                return imagecreatefromjpeg($file_path);
            case 'image/png':
                return imagecreatefrompng($file_path);
            case 'image/gif':
                return imagecreatefromgif($file_path);
            case 'image/webp':
                return imagecreatefromwebp($file_path);
            default:
                return false;
        }
    }
    
    /**
     * Save image to file
     * 
     * @param resource $image Image resource
     * @param string $file_path File path
     * @param string $mime_type MIME type
     * @param int $quality Image quality
     * @return bool Success or failure
     */
    private function saveImage($image, $file_path, $mime_type, $quality) {
        switch ($mime_type) {
            case 'image/jpeg':
                return imagejpeg($image, $file_path, $quality);
            case 'image/png':
                // PNG quality is 0-9, convert from 0-100
                $png_quality = 9 - floor(($quality / 100) * 9);
                return imagepng($image, $file_path, $png_quality);
            case 'image/gif':
                return imagegif($image, $file_path);
            case 'image/webp':
                return imagewebp($image, $file_path, $quality);
            default:
                return false;
        }
    }
    
    /**
     * Get optimized image URL
     * 
     * @param string $image_path Image path
     * @param int $width Width (optional)
     * @param int $height Height (optional)
     * @return string Optimized image URL
     */
    public function getOptimizedUrl($image_path, $width = null, $height = null) {
        // Check if image exists
        if (!file_exists($image_path)) {
            return '';
        }
        
        // Set default values
        $width = $width ?? $this->max_width;
        $height = $height ?? $this->max_height;
        
        // Generate cache key
        $pathinfo = pathinfo($image_path);
        $cache_key = $pathinfo['filename'] . '_' . $width . 'x' . $height . '.' . $pathinfo['extension'];
        $cache_path = $this->cache_dir . '/' . $cache_key;
        
        // Check if cached image exists
        if (!file_exists($cache_path)) {
            // Optimize image
            $this->optimize($image_path, $cache_path, $this->quality, $width, $height);
        }
        
        // Return URL
        $cache_url = str_replace(dirname(__DIR__), '', $cache_path);
        $cache_url = str_replace('\\', '/', $cache_url);
        
        return $cache_url;
    }
}

// Create image optimizer instance
$image_optimizer = new ImageOptimizer();

/**
 * Get optimized image URL
 * 
 * @param string $image_path Image path
 * @param int $width Width (optional)
 * @param int $height Height (optional)
 * @return string Optimized image URL
 */
function get_optimized_image($image_path, $width = null, $height = null) {
    global $image_optimizer;
    return $image_optimizer->getOptimizedUrl($image_path, $width, $height);
}
?>