<?php
/**
 * CSS and JavaScript Minifier
 * LelangMobil Web App - Versi 2025
 */

class Minifier {
    private $cache_dir;
    private $cache_time;
    
    public function __construct($cache_dir = null, $cache_time = 86400) {
        $this->cache_dir = $cache_dir ?? dirname(__DIR__) . '/cache/minified';
        $this->cache_time = $cache_time;
        
        // Create cache directory if it doesn't exist
        if (!file_exists($this->cache_dir)) {
            mkdir($this->cache_dir, 0755, true);
        }
    }
    
    /**
     * Minify CSS file
     * 
     * @param string|array $files CSS file path(s)
     * @param string $output_file Output file name (optional)
     * @return string Minified CSS file URL
     */
    public function minifyCss($files, $output_file = null) {
        // Convert single file to array
        if (!is_array($files)) {
            $files = [$files];
        }
        
        // Generate output file name if not provided
        if ($output_file === null) {
            $output_file = md5(implode('', $files)) . '.min.css';
        }
        
        $output_path = $this->cache_dir . '/' . $output_file;
        
        // Check if cached file exists and is not expired
        if (file_exists($output_path) && (time() - filemtime($output_path) < $this->cache_time)) {
            return $this->getUrl($output_path);
        }
        
        // Read and minify CSS files
        $css = '';
        
        foreach ($files as $file) {
            if (file_exists($file)) {
                $css .= file_get_contents($file);
            }
        }
        
        // Minify CSS
        $css = $this->minifyCssContent($css);
        
        // Save minified CSS
        file_put_contents($output_path, $css);
        
        return $this->getUrl($output_path);
    }
    
    /**
     * Minify JavaScript file
     * 
     * @param string|array $files JavaScript file path(s)
     * @param string $output_file Output file name (optional)
     * @return string Minified JavaScript file URL
     */
    public function minifyJs($files, $output_file = null) {
        // Convert single file to array
        if (!is_array($files)) {
            $files = [$files];
        }
        
        // Generate output file name if not provided
        if ($output_file === null) {
            $output_file = md5(implode('', $files)) . '.min.js';
        }
        
        $output_path = $this->cache_dir . '/' . $output_file;
        
        // Check if cached file exists and is not expired
        if (file_exists($output_path) && (time() - filemtime($output_path) < $this->cache_time)) {
            return $this->getUrl($output_path);
        }
        
        // Read and minify JavaScript files
        $js = '';
        
        foreach ($files as $file) {
            if (file_exists($file)) {
                $js .= file_get_contents($file) . ";\n";
            }
        }
        
        // Minify JavaScript
        $js = $this->minifyJsContent($js);
        
        // Save minified JavaScript
        file_put_contents($output_path, $js);
        
        return $this->getUrl($output_path);
    }
    
    /**
     * Minify CSS content
     * 
     * @param string $css CSS content
     * @return string Minified CSS content
     */
    private function minifyCssContent($css) {
        // Remove comments
        $css = preg_replace('!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css);
        
        // Remove whitespace
        $css = preg_replace('/\s+/', ' ', $css);
        
        // Remove spaces before and after symbols
        $css = preg_replace('/\s*({|}|,|:|;)\s*/', '$1', $css);
        
        // Remove unnecessary semicolons
        $css = preg_replace('/;}/', '}', $css);
        
        return trim($css);
    }
    
    /**
     * Minify JavaScript content
     * 
     * @param string $js JavaScript content
     * @return string Minified JavaScript content
     */
    private function minifyJsContent($js) {
        // Remove comments (single line and multi-line)
        $js = preg_replace('/((?:\/\*(?:[^*]|(?:\*+[^*\/]))*\*+\/)|(?:\/\/.*))/', '', $js);
        
        // Remove whitespace
        $js = preg_replace('/\s+/', ' ', $js);
        
        // Remove spaces before and after symbols
        $js = preg_replace('/\s*({|}|,|:|;|\(|\)|\[|\])\s*/', '$1', $js);
        
        // Remove unnecessary semicolons
        $js = preg_replace('/;}/', '}', $js);
        
        return trim($js);
    }
    
    /**
     * Get URL from file path
     * 
     * @param string $file_path File path
     * @return string File URL
     */
    private function getUrl($file_path) {
        $url = str_replace(dirname(__DIR__), '', $file_path);
        $url = str_replace('\\', '/', $url);
        
        return $url;
    }
}

// Create minifier instance
$minifier = new Minifier();

/**
 * Get minified CSS URL
 * 
 * @param string|array $files CSS file path(s)
 * @param string $output_file Output file name (optional)
 * @return string Minified CSS file URL
 */
function get_minified_css($files, $output_file = null) {
    global $minifier;
    return $minifier->minifyCss($files, $output_file);
}

/**
 * Get minified JavaScript URL
 * 
 * @param string|array $files JavaScript file path(s)
 * @param string $output_file Output file name (optional)
 * @return string Minified JavaScript file URL
 */
function get_minified_js($files, $output_file = null) {
    global $minifier;
    return $minifier->minifyJs($files, $output_file);
}
?>