<?php
/**
 * Validation Helper Functions
 * LelangMobil Web App - Versi 2025
 */

/**
 * Validate email
 * 
 * @param string $email Email to validate
 * @return bool Is valid
 */
function validate_email($email) {
    return filter_var($email, FILTER_VALIDATE_EMAIL) !== false;
}

/**
 * Validate username
 * 
 * @param string $username Username to validate
 * @return bool Is valid
 */
function validate_username($username) {
    // Only allow alphanumeric characters, underscore and dash
    return preg_match('/^[a-zA-Z0-9_-]{3,20}$/', $username);
}

/**
 * Validate password strength
 * 
 * @param string $password Password to validate
 * @return bool Is strong enough
 */
function validate_password_strength($password) {
    // At least 8 characters
    if (strlen($password) < 8) {
        return false;
    }
    
    // Check for at least one uppercase letter, one lowercase letter, and one number
    $has_uppercase = preg_match('/[A-Z]/', $password);
    $has_lowercase = preg_match('/[a-z]/', $password);
    $has_number = preg_match('/[0-9]/', $password);
    
    return $has_uppercase && $has_lowercase && $has_number;
}

/**
 * Validate phone number
 * 
 * @param string $phone Phone number to validate
 * @return bool Is valid
 */
function validate_phone($phone) {
    // Remove spaces, dashes, and parentheses
    $phone = preg_replace('/[\s\-\(\)]/', '', $phone);
    
    // Check if it's a valid Indonesian phone number
    return preg_match('/^(\+62|62|0)[0-9]{9,12}$/', $phone);
}

/**
 * Validate amount
 * 
 * @param float $amount Amount to validate
 * @param float $min Minimum amount
 * @return bool Is valid
 */
function validate_amount($amount, $min = 0) {
    return is_numeric($amount) && $amount >= $min;
}

/**
 * Validate date
 * 
 * @param string $date Date to validate
 * @param string $format Date format
 * @return bool Is valid
 */
function validate_date($date, $format = 'Y-m-d') {
    $d = DateTime::createFromFormat($format, $date);
    return $d && $d->format($format) === $date;
}

/**
 * Validate file type
 * 
 * @param string $file_type File MIME type
 * @param array $allowed_types Allowed MIME types
 * @return bool Is valid
 */
function validate_file_type($file_type, $allowed_types) {
    return in_array($file_type, $allowed_types);
}

/**
 * Validate file size
 * 
 * @param int $file_size File size in bytes
 * @param int $max_size Maximum size in bytes
 * @return bool Is valid
 */
function validate_file_size($file_size, $max_size) {
    return $file_size <= $max_size;
}

/**
 * Validate image dimensions
 * 
 * @param string $file_path Path to image file
 * @param int $min_width Minimum width
 * @param int $min_height Minimum height
 * @param int $max_width Maximum width
 * @param int $max_height Maximum height
 * @return bool Is valid
 */
function validate_image_dimensions($file_path, $min_width = 0, $min_height = 0, $max_width = 10000, $max_height = 10000) {
    $image_info = getimagesize($file_path);
    
    if ($image_info === false) {
        return false;
    }
    
    $width = $image_info[0];
    $height = $image_info[1];
    
    return $width >= $min_width && $height >= $min_height && $width <= $max_width && $height <= $max_height;
}

/**
 * Sanitize input
 * 
 * @param string $input Input to sanitize
 * @return string Sanitized input
 */
function sanitize_input($input) {
    return htmlspecialchars(trim($input), ENT_QUOTES, 'UTF-8');
}

/**
 * Sanitize email
 * 
 * @param string $email Email to sanitize
 * @return string Sanitized email
 */
function sanitize_email($email) {
    return filter_var(trim($email), FILTER_SANITIZE_EMAIL);
}

/**
 * Sanitize username
 * 
 * @param string $username Username to sanitize
 * @return string Sanitized username
 */
function sanitize_username($username) {
    // Remove any characters that aren't alphanumeric, underscore or dash
    return preg_replace('/[^a-zA-Z0-9_-]/', '', $username);
}

/**
 * Sanitize phone number
 * 
 * @param string $phone Phone number to sanitize
 * @return string Sanitized phone number
 */
function sanitize_phone($phone) {
    // Remove any non-digit characters
    return preg_replace('/[^0-9+]/', '', $phone);
}
?>