/**
 * Modern Components JavaScript
 * LelangMobil Web App - Versi 2025
 * Komponen untuk Featured Auctions, How It Works, Testimonials, dan CTA
 */

document.addEventListener('DOMContentLoaded', function() {
    // Initialize AOS animations
    AOS.init({
        duration: 800,
        easing: 'ease-in-out',
        once: true,
        mirror: false
    });
    
    // Initialize Featured Auctions carousel
    initFeaturedCarousel();
    
    // Initialize Testimonials swiper
    initTestimonialsSwiper();
    
    // Initialize countdown timers
    initCountdownTimers();
    
    // Initialize category tabs 
    initCategoryTabs();
    
    // Initialize stats counters
    initCounters();
});

/**
 * Initialize Featured Auctions carousel
 */
function initFeaturedCarousel() {
    const carousels = document.querySelectorAll('.featured-carousel');
    
    if (carousels.length) {
        carousels.forEach(carousel => {
            new OwlCarousel(carousel, {
                loop: true,
                margin: 20,
                nav: true,
                dots: true,
                autoplay: true,
                autoplayTimeout: 5000,
                autoplayHoverPause: true,
                navText: [
                    '<i class="fas fa-chevron-left"></i>',
                    '<i class="fas fa-chevron-right"></i>'
                ],
                responsive: {
                    0: {
                        items: 1
                    },
                    576: {
                        items: 2
                    },
                    992: {
                        items: 3
                    },
                    1200: {
                        items: 4
                    }
                }
            });
        });
    }
}

/**
 * Initialize Testimonials Swiper
 */
function initTestimonialsSwiper() {
    const testimonialsContainer = document.querySelector('.testimonials-swiper');
    
    if (testimonialsContainer) {
        new Swiper(testimonialsContainer, {
            slidesPerView: 1,
            spaceBetween: 30,
            loop: true,
            autoplay: {
                delay: 5000,
                disableOnInteraction: false,
            },
            pagination: {
                el: '.testimonials-pagination',
                clickable: true,
            },
            navigation: {
                nextEl: '.testimonials-button-next',
                prevEl: '.testimonials-button-prev',
            },
            breakpoints: {
                640: {
                    slidesPerView: 1,
                    spaceBetween: 20,
                },
                768: {
                    slidesPerView: 2,
                    spaceBetween: 30,
                },
                1024: {
                    slidesPerView: 3,
                    spaceBetween: 30,
                },
            }
        });
    }
}

/**
 * Initialize Auction Countdown Timers
 */
function initCountdownTimers() {
    const countdownElements = document.querySelectorAll('.auction-countdown');
    
    if (countdownElements.length) {
        countdownElements.forEach(element => {
            const endTime = new Date(element.getAttribute('data-end-time')).getTime();
            
            // Update countdown every second
            const timer = setInterval(function() {
                // Get current date and time
                const now = new Date().getTime();
                
                // Calculate the time remaining
                const distance = endTime - now;
                
                // Calculate days, hours, minutes, and seconds
                const days = Math.floor(distance / (1000 * 60 * 60 * 24));
                const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
                const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
                const seconds = Math.floor((distance % (1000 * 60)) / 1000);
                
                // Display the result
                let displayText = '';
                
                if (days > 0) {
                    displayText += days + 'd ';
                }
                
                if (hours > 0 || days > 0) {
                    displayText += hours + 'h ';
                }
                
                displayText += minutes + 'm ' + seconds + 's';
                
                element.textContent = displayText;
                
                // If the countdown is finished, display expired text
                if (distance < 0) {
                    clearInterval(timer);
                    element.textContent = 'EXPIRED';
                    element.closest('.auction-time-left').style.backgroundColor = '#f44336';
                }
            }, 1000);
        });
    }
}

/**
 * Initialize Category Tabs functionality
 */
function initCategoryTabs() {
    const categoryTabs = document.querySelectorAll('.category-tab');
    
    if (categoryTabs.length) {
        categoryTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                const category = this.getAttribute('data-category');
                
                // Show loading message in tab content
                const tabContent = document.querySelector(`.auction-category-container[data-category="${category}"]`);
                
                if (category !== 'all' && tabContent && tabContent.innerHTML.includes('Memuat lelang kategori')) {
                    // Simulate loading data for the category
                    // In a real application, this would be an AJAX call to fetch data from the server
                    setTimeout(() => {
                        // Clone the 'all' tab content
                        const allTabContent = document.querySelector('.auction-category-container[data-category="all"]');
                        
                        if (allTabContent) {
                            const clonedContent = allTabContent.cloneNode(true);
                            
                            // Modify the cloned content to show it's filtered
                            const auctionTitle = document.createElement('div');
                            auctionTitle.className = 'category-filter-info mb-4 text-center';
                            auctionTitle.innerHTML = `<p>Menampilkan lelang kategori <strong>${category.toUpperCase()}</strong></p>`;
                            
                            // Replace the tab content
                            tabContent.innerHTML = '';
                            tabContent.appendChild(auctionTitle);
                            tabContent.appendChild(clonedContent.querySelector('.featured-carousel'));
                            tabContent.appendChild(clonedContent.querySelector('.text-center.mt-4'));
                            
                            // Reinitialize the carousel
                            initFeaturedCarousel();
                        }
                    }, 800);
                }
            });
        });
    }
}

/**
 * Initialize Statistics Counters
 */
function initCounters() {
    const counters = document.querySelectorAll('.counter');
    
    if (counters.length) {
        counters.forEach(counter => {
            const target = +counter.getAttribute('data-count');
            const duration = 2000;
            const startTime = Date.now();
            const startValue = 0;
            
            function updateCounter() {
                const currentTime = Date.now();
                const elapsed = currentTime - startTime;
                
                if (elapsed < duration) {
                    // Calculate current value based on easing function
                    const progress = elapsed / duration;
                    const easedProgress = easeOutQuart(progress);
                    const currentValue = Math.floor(startValue + (target - startValue) * easedProgress);
                    
                    // Update counter text
                    counter.textContent = currentValue.toLocaleString('id-ID') + '+';
                    
                    // Continue animation
                    requestAnimationFrame(updateCounter);
                } else {
                    // Animation completed
                    counter.textContent = target.toLocaleString('id-ID') + '+';
                }
            }
            
            // Start animation when element is in viewport
            const observer = new IntersectionObserver((entries) => {
                entries.forEach(entry => {
                    if (entry.isIntersecting) {
                        updateCounter();
                        observer.disconnect();
                    }
                });
            }, { threshold: 0.1 });
            
            observer.observe(counter);
        });
    }
}

/**
 * Easing function for smooth counter animation
 */
function easeOutQuart(x) {
    return 1 - Math.pow(1 - x, 4);
}
