document.addEventListener('DOMContentLoaded', function() {
    // Initialize WebSocket handler
    const ws = new WebSocketHandler();
    
    // Subscribe to vehicle updates
    const vehicleId = document.body.dataset.vehicleId;
    if (vehicleId) {
        ws.subscribe(`vehicle_${vehicleId}`, (data) => {
            if (data.type === 'bid_update') {
                // Update minimum bid amount
                const bidInput = document.querySelector('#bidAmount');
                if (bidInput) {
                    bidInput.min = data.amount + 1;
                    bidInput.nextElementSibling.textContent = `Bid minimum: Rp${new Intl.NumberFormat('id-ID').format(data.amount + 1)}`;
                }
            }
        });
    }
    
    // Image gallery functionality with lazy loading
    const thumbnails = document.querySelectorAll('.thumbnail');
    const mainImage = document.querySelector('.vehicle-image-main img');
    
    thumbnails.forEach(thumbnail => {
        thumbnail.addEventListener('click', function() {
            const newSrc = this.dataset.src || this.src;
            mainImage.dataset.src = newSrc;
            mainImage.src = newSrc;
        });
    });
    
    // Auto-bid form handling
    const autoBidForm = document.getElementById('autoBidForm');
    if (autoBidForm) {
        autoBidForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            const formData = new FormData(this);
            formData.append('vehicle_id', vehicleId);
            
            fetch('api/auto-bid.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    ws.showNotification({
                        title: 'Auto-Bid',
                        message: 'Auto-bid berhasil diaktifkan',
                        type: 'success'
                    });
                } else {
                    ws.showNotification({
                        title: 'Error',
                        message: data.message,
                        type: 'error'
                    });
                }
            });
        });
    }
    
    // Comment form handling
    const commentForm = document.getElementById('commentForm');
    if (commentForm) {
        commentForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            const comment = this.querySelector('[name="comment"]').value;
            
            fetch('api/comment.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    vehicle_id: vehicleId,
                    comment: comment
                })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    ws.showNotification({
                        title: 'Komentar',
                        message: data.message,
                        type: 'success'
                    });
                    this.reset();
                    
                    // Add comment to list if approved immediately
                    if (data.comment) {
                        const commentsList = document.getElementById('commentsList');
                        const newComment = document.createElement('div');
                        newComment.className = 'comment mb-3';
                        newComment.innerHTML = `
                            <div class="d-flex">
                                <div class="comment-avatar">
                                    <i class="fa fa-user-circle fa-2x"></i>
                                </div>
                                <div class="comment-content ms-3">
                                    <div class="comment-header">
                                        <strong>${data.comment.user_name}</strong>
                                        <small class="text-muted ms-2">
                                            ${new Date().toLocaleString('id-ID')}
                                        </small>
                                    </div>
                                    <div class="comment-text">
                                        ${data.comment.comment}
                                    </div>
                                </div>
                            </div>
                        `;
                        commentsList.insertBefore(newComment, commentsList.firstChild);
                    }
                } else {
                    ws.showNotification({
                        title: 'Error',
                        message: data.message,
                        type: 'error'
                    });
                }
            });
        });
    }
    
    // Rating form handling
    const ratingForm = document.getElementById('ratingForm');
    if (ratingForm) {
        ratingForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            const rating = this.querySelector('input[name="rating"]:checked')?.value;
            const comment = this.querySelector('[name="rating_comment"]').value;
            
            if (!rating) {
                ws.showNotification({
                    title: 'Error',
                    message: 'Silakan pilih rating',
                    type: 'error'
                });
                return;
            }
            
            fetch('api/rating.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    seller_id: document.body.dataset.sellerId,
                    rating: rating,
                    comment: comment
                })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    ws.showNotification({
                        title: 'Rating',
                        message: data.message,
                        type: 'success'
                    });
                    this.reset();
                } else {
                    ws.showNotification({
                        title: 'Error',
                        message: data.message,
                        type: 'error'
                    });
                }
            });
        });
    }
    
    // Favorite button handling
    const favoriteBtn = document.getElementById('favoriteBtn');
    if (favoriteBtn) {
        favoriteBtn.addEventListener('click', function() {
            fetch('api/favorite.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ vehicle_id: vehicleId })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    this.classList.toggle('active');
                    this.innerHTML = data.is_favorite ? 
                        '<i class="fa fa-heart"></i> Hapus dari Favorit' :
                        '<i class="fa fa-heart"></i> Tambah ke Favorit';
                    ws.showNotification({
                        title: 'Favorit',
                        message: data.message,
                        type: 'success'
                    });
                }
            });
        });
    }
});