/**
 * Performance Optimizations for Vehicle Pages
 * LelangMobil Premium Auction System
 * Version: 1.0 (2025-05-02)
 */

document.addEventListener('DOMContentLoaded', function() {
    // Lazy loading gambar
    initLazyLoading();
    
    // Throttle dan debounce event untuk performa
    optimizeEventListeners();
    
    // Deteksi perangkat untuk pengalaman yang lebih baik
    detectDeviceCapabilities();
    
    // Optimasi animasi untuk perangkat dengan performa rendah
    optimizeAnimations();
});

/**
 * Inisialisasi lazy loading untuk gambar
 */
function initLazyLoading() {
    // Gunakan IntersectionObserver untuk lazy loading image yang efisien
    if ('IntersectionObserver' in window) {
        const imageObserver = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    const lazyImage = entry.target;
                    if (lazyImage.dataset.src) {
                        lazyImage.src = lazyImage.dataset.src;
                        lazyImage.removeAttribute('data-src');
                        lazyImage.classList.add('loaded');
                        imageObserver.unobserve(lazyImage);
                    }
                }
            });
        }, {
            rootMargin: '200px 0px' // Pre-load gambar 200px sebelum masuk viewport
        });
        
        // Terapkan ke semua gambar dengan data-src
        document.querySelectorAll('img[data-src]').forEach(img => {
            imageObserver.observe(img);
        });
        
        // Konversi thumbnail dan galeri ke lazy loading
        convertToLazyLoad();
    } else {
        // Fallback untuk browser yang tidak mendukung IntersectionObserver
        document.querySelectorAll('img[data-src]').forEach(img => {
            img.src = img.dataset.src;
            img.removeAttribute('data-src');
        });
    }
}

/**
 * Konversi gambar eksisting ke lazy loading format
 */
function convertToLazyLoad() {
    // Cari semua gambar di galeri dan thumbnail yang belum lazy load
    const galleryImages = document.querySelectorAll('.carousel-item img:not([data-src])');
    
    galleryImages.forEach(img => {
        if (!img.dataset.src && img.src) {
            // Simpan URL gambar asli ke data-src
            img.dataset.src = img.src;
            // Tambahkan placeholder sementara (very small blurred image)
            img.src = 'data:image/svg+xml,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1 1"%3E%3C/svg%3E';
            // Tambahkan kelas untuk styling
            img.classList.add('lazy');
        }
    });
}

/**
 * Optimasi event listener dengan throttle dan debounce
 */
function optimizeEventListeners() {
    // Throttle function untuk scroll events
    function throttle(func, delay) {
        let lastCall = 0;
        return function(...args) {
            const now = new Date().getTime();
            if (now - lastCall >= delay) {
                lastCall = now;
                func(...args);
            }
        };
    }
    
    // Debounce function untuk resize events
    function debounce(func, delay) {
        let timer;
        return function(...args) {
            clearTimeout(timer);
            timer = setTimeout(() => func(...args), delay);
        };
    }
    
    // Scroll event yang di-throttle untuk parallax
    const parallaxContainer = document.getElementById('vehicle-hero');
    if (parallaxContainer) {
        const handleParallax = throttle(function() {
            const scrollY = window.scrollY;
            const heroHeight = parallaxContainer.offsetHeight;
            
            if (scrollY <= heroHeight) {
                const parallaxOffset = scrollY * 0.4;
                // Menggunakan transform untuk performa yang lebih baik
                parallaxContainer.style.transform = `translateY(${parallaxOffset * 0.5}px)`;
                
                // Opacity dengan transform untuk performa yang lebih baik
                const heroContent = parallaxContainer.querySelector('.vehicle-hero-content');
                if (heroContent) {
                    const opacity = 1 - (scrollY / heroHeight * 1.2);
                    heroContent.style.opacity = Math.max(0, opacity);
                }
            }
        }, 16); // ~ 60fps
        
        window.addEventListener('scroll', handleParallax, { passive: true });
    }
    
    // Resize event yang di-debounce
    const handleResize = debounce(function() {
        adjustLayoutForScreenSize();
    }, 150);
    
    window.addEventListener('resize', handleResize, { passive: true });
}

/**
 * Menyesuaikan layout berdasarkan ukuran layar
 */
function adjustLayoutForScreenSize() {
    const isMobile = window.innerWidth < 768;
    const isTablet = window.innerWidth >= 768 && window.innerWidth < 992;
    
    // Adjust card height for consistency
    const infoBoxes = document.querySelectorAll('.info-box');
    if (isMobile) {
        infoBoxes.forEach(box => box.style.height = 'auto');
    } else {
        equalizeHeights(infoBoxes);
    }
    
    // Adjust timer size
    const timerBlocks = document.querySelectorAll('.timer-block .number');
    timerBlocks.forEach(block => {
        block.style.fontSize = isMobile ? '1.5rem' : isTablet ? '1.8rem' : '2rem';
    });
    
    // Adjust bid history
    const bidHistory = document.querySelector('.bid-history');
    if (bidHistory) {
        bidHistory.style.maxHeight = isMobile ? '200px' : '300px';
    }
}

/**
 * Menyamakan tinggi elemen-elemen untuk tampilan yang konsisten
 */
function equalizeHeights(elements) {
    // Reset heights
    elements.forEach(el => el.style.height = 'auto');
    
    // Calculate max height
    let maxHeight = 0;
    elements.forEach(el => {
        maxHeight = Math.max(maxHeight, el.offsetHeight);
    });
    
    // Apply equal height
    elements.forEach(el => {
        el.style.height = maxHeight + 'px';
    });
}

/**
 * Deteksi kemampuan perangkat untuk pengalaman yang lebih baik
 */
function detectDeviceCapabilities() {
    const htmlElement = document.documentElement;
    
    // Deteksi touch device
    const isTouch = 'ontouchstart' in window || navigator.maxTouchPoints > 0;
    htmlElement.classList.toggle('touch-device', isTouch);
    
    // Deteksi low-end device berdasarkan hardware concurrency
    const isLowEnd = !navigator.hardwareConcurrency || navigator.hardwareConcurrency <= 2;
    htmlElement.classList.toggle('low-end-device', isLowEnd);
    
    // Deteksi battery status jika tersedia
    if ('getBattery' in navigator) {
        navigator.getBattery().then(battery => {
            const isLowBattery = battery.level < 0.2 && !battery.charging;
            htmlElement.classList.toggle('low-battery', isLowBattery);
            
            // Kurangi animasi di mode baterai rendah
            if (isLowBattery) {
                reduceAnimations();
            }
        });
    }
    
    // Detect reduced motion preference
    const prefersReducedMotion = window.matchMedia('(prefers-reduced-motion: reduce)');
    if (prefersReducedMotion.matches) {
        reduceAnimations();
    }
}

/**
 * Optimasi animasi berdasarkan kemampuan perangkat
 */
function optimizeAnimations() {
    const htmlElement = document.documentElement;
    
    // Helper untuk mengecek apakah elemen berada dalam viewport
    function isInViewport(element) {
        const rect = element.getBoundingClientRect();
        return (
            rect.top <= (window.innerHeight || document.documentElement.clientHeight) &&
            rect.left <= (window.innerWidth || document.documentElement.clientWidth) &&
            rect.bottom >= 0 &&
            rect.right >= 0
        );
    }
    
    // Hanya animasikan elemen yang visible
    const animateVisibleElements = throttle(function() {
        const animatableElements = document.querySelectorAll('.fade-in, .fade-in-up, .bid-history-item');
        
        animatableElements.forEach(element => {
            if (isInViewport(element) && !element.classList.contains('animated')) {
                element.classList.add('animated');
            }
        });
    }, 100);
    
    window.addEventListener('scroll', animateVisibleElements, { passive: true });
    
    // Initial call
    animateVisibleElements();
    
    // Optimization untuk low-end devices
    if (htmlElement.classList.contains('low-end-device') || 
        htmlElement.classList.contains('low-battery')) {
        reduceAnimations();
    }
}

/**
 * Kurangi animasi untuk perangkat dengan performa rendah
 */
function reduceAnimations() {
    document.documentElement.classList.add('reduced-motion');
    
    // Simpan animasi original di data attribute
    document.querySelectorAll('.animate__animated').forEach(el => {
        const currentClasses = el.className;
        el.setAttribute('data-original-animation', currentClasses);
        el.classList.remove('animate__animated');
        
        // Hapus semua class animasi
        Array.from(el.classList).forEach(cls => {
            if (cls.startsWith('animate__')) {
                el.classList.remove(cls);
            }
        });
    });
    
    // Kurangi efek hover yang berat
    const style = document.createElement('style');
    style.textContent = `
        .reduced-motion .info-box:hover,
        .reduced-motion .thumbnail:hover,
        .reduced-motion .bid-history-item:hover {
            transform: none !important;
            transition: background-color 0.3s ease !important;
        }
        
        .reduced-motion .progress-bar::after,
        .reduced-motion .btn-preset::before,
        .reduced-motion .premium-bid-btn .btn-overlay {
            animation: none !important;
        }
        
        .reduced-motion .fade-in,
        .reduced-motion .fade-in-up,
        .reduced-motion .bid-history-item {
            opacity: 1 !important;
            transform: none !important;
            transition: none !important;
            animation: none !important;
        }
    `;
    document.head.appendChild(style);
}

// Fungsi throttle untuk mengoptimalkan event handler
function throttle(func, delay) {
    let lastCall = 0;
    return function(...args) {
        const now = new Date().getTime();
        if (now - lastCall >= delay) {
            lastCall = now;
            func(...args);
        }
    };
}

// Inisialisasi saat dokumen telah dimuat
document.addEventListener('DOMContentLoaded', function() {
    // Pra-konfigurasi image size yang tepat
    setupOptimalImageSizes();
    
    // Mengukur dan memperbaiki Cumulative Layout Shift
    fixLayoutShift();
});

/**
 * Mengatur ukuran gambar optimal berdasarkan ukuran layar
 */
function setupOptimalImageSizes() {
    // Configure srcset untuk gambar responsif
    const galleryImages = document.querySelectorAll('.carousel-item img');
    
    galleryImages.forEach(img => {
        const originalSrc = img.getAttribute('src') || img.getAttribute('data-src');
        if (originalSrc && !img.getAttribute('srcset')) {
            // Buat srcset alternatif jika tidak ada
            const path = originalSrc.split('.');
            const ext = path.pop();
            const base = path.join('.');
            
            // Set srcset dengan berbagai ukuran berdasarkan original path
            const srcset = `
                ${base}-small.${ext} 576w,
                ${base}-medium.${ext} 992w,
                ${base}.${ext} 1200w
            `;
            
            img.setAttribute('srcset', srcset);
            img.setAttribute('sizes', '(max-width: 576px) 100vw, (max-width: 992px) 50vw, 33vw');
        }
    });
}

/**
 * Memperbaiki Cumulative Layout Shift
 */
function fixLayoutShift() {
    // Set placeholder dimensions untuk mencegah layout shift
    const carouselItems = document.querySelectorAll('.carousel-item');
    
    carouselItems.forEach(item => {
        // Set ratio 16:9 for image containers
        item.style.paddingBottom = '56.25%';
        item.style.position = 'relative';
        
        const img = item.querySelector('img');
        if (img) {
            img.style.position = 'absolute';
            img.style.top = '0';
            img.style.left = '0';
            img.style.width = '100%';
            img.style.height = '100%';
            img.style.objectFit = 'cover';
        }
    });
}
