<?php
/**
 * Modern Profile Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Get user information
try {
    $user_sql = "SELECT * FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
} catch (Throwable $e) {
    die("Error fetching user data: " . $e->getMessage());
}

// Process profile update
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_profile'])) {
    $full_name = clean_input($_POST['full_name']);
    $email = clean_input($_POST['email']);
    $phone = clean_input($_POST['phone']);
    $bio = clean_input($_POST['bio']);
    
    // Validate email
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "Format email tidak valid.";
    } 
    // Validate phone number
    elseif (!empty($phone) && !preg_match('/^[0-9+\-\s]{8,15}$/', $phone)) {
        $error = "Format nomor telepon tidak valid.";
    } 
    else {
        try {
            // Check if email already exists for another user
            if ($email != $user['email']) {
                $check_email_sql = "SELECT user_id FROM users WHERE email = ? AND user_id != ?";
                $check_email_stmt = $conn->prepare($check_email_sql);
                $check_email_stmt->bind_param("si", $email, $user_id);
                $check_email_stmt->execute();
                $check_email_result = $check_email_stmt->get_result();
                
                if ($check_email_result->num_rows > 0) {
                    $error = "Email sudah digunakan oleh pengguna lain.";
                }
            }
            
            if (empty($error)) {
                // Update profile
                $update_sql = "UPDATE users SET full_name = ?, email = ?, phone = ?, bio = ? WHERE user_id = ?";
                $update_stmt = $conn->prepare($update_sql);
                $update_stmt->bind_param("ssssi", $full_name, $email, $phone, $bio, $user_id);
                
                if ($update_stmt->execute()) {
                    $success = "Profil berhasil diperbarui.";
                    
                    // Refresh user data
                    $user_stmt->execute();
                    $user_result = $user_stmt->get_result();
                    $user = $user_result->fetch_assoc();
                } else {
                    $error = "Gagal memperbarui profil: " . $conn->error;
                }
            }
        } catch (Throwable $e) {
            $error = "Terjadi kesalahan: " . $e->getMessage();
        }
    }
}

// Process profile picture update
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_picture'])) {
    if (isset($_FILES['profile_picture']) && $_FILES['profile_picture']['error'] == 0) {
        $allowed_types = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif'];
        $max_size = 2 * 1024 * 1024; // 2MB
        
        if (!in_array($_FILES['profile_picture']['type'], $allowed_types)) {
            $error = "Jenis file tidak didukung. Gunakan format JPG, JPEG, PNG, atau GIF.";
        } elseif ($_FILES['profile_picture']['size'] > $max_size) {
            $error = "Ukuran file terlalu besar. Maksimal 2MB.";
        } else {
            // Create upload directory if it doesn't exist
            $upload_dir = 'uploads/profile_pictures/';
            if (!file_exists($upload_dir)) {
                mkdir($upload_dir, 0777, true);
            }
            
            // Generate unique filename
            $file_extension = pathinfo($_FILES['profile_picture']['name'], PATHINFO_EXTENSION);
            $filename = 'profile_' . $user_id . '_' . time() . '.' . $file_extension;
            $target_file = $upload_dir . $filename;
            
            if (move_uploaded_file($_FILES['profile_picture']['tmp_name'], $target_file)) {
                // Update profile picture in database
                $update_sql = "UPDATE users SET profile_image = ? WHERE user_id = ?";
                $update_stmt = $conn->prepare($update_sql);
                $update_stmt->bind_param("si", $target_file, $user_id);
                
                if ($update_stmt->execute()) {
                    $success = "Foto profil berhasil diperbarui.";
                    
                    // Refresh user data
                    $user_stmt->execute();
                    $user_result = $user_stmt->get_result();
                    $user = $user_result->fetch_assoc();
                } else {
                    $error = "Gagal memperbarui foto profil: " . $conn->error;
                }
            } else {
                $error = "Gagal mengunggah file. Silakan coba lagi.";
            }
        }
    } else {
        $error = "Silakan pilih file untuk diunggah.";
    }
}

// Process password update
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_password'])) {
    $current_password = $_POST['current_password'];
    $new_password = $_POST['new_password'];
    $confirm_password = $_POST['confirm_password'];
    
    // Validate password
    if (empty($current_password) || empty($new_password) || empty($confirm_password)) {
        $error = "Semua field password harus diisi.";
    } elseif ($new_password != $confirm_password) {
        $error = "Password baru dan konfirmasi password tidak cocok.";
    } elseif (strlen($new_password) < 8) {
        $error = "Password baru minimal 8 karakter.";
    } else {
        try {
            // Verify current password
            if (password_verify($current_password, $user['password'])) {
                // Update password
                $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
                $update_sql = "UPDATE users SET password = ? WHERE user_id = ?";
                $update_stmt = $conn->prepare($update_sql);
                $update_stmt->bind_param("si", $hashed_password, $user_id);
                
                if ($update_stmt->execute()) {
                    $success = "Password berhasil diperbarui.";
                } else {
                    $error = "Gagal memperbarui password: " . $conn->error;
                }
            } else {
                $error = "Password saat ini tidak valid.";
            }
        } catch (Throwable $e) {
            $error = "Terjadi kesalahan: " . $e->getMessage();
        }
    }
}

// Set page title and flags
$page_title = "Profil Saya";
$is_dashboard_page = true;
$use_modern_dashboard = true;
$page_specific_css = '<link href="css/modern-effects.css" rel="stylesheet">';

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <h2 class="mb-4 fade-in"><?php echo $page_title; ?></h2>
            
            <!-- Profile Header -->
            <div class="modern-card profile-header mb-4 slide-down">
                <div class="modern-card-body">
                    <div class="row align-items-center">
                        <div class="col-md-2 text-center">
                            <div class="profile-picture-container">
                                <?php if (!empty($user['profile_image'])): ?>
                                <img src="<?php echo $user['profile_image']; ?>" alt="<?php echo $user['username']; ?>" class="profile-picture">
                                <?php else: ?>
                                <div class="profile-picture-placeholder">
                                    <?php echo strtoupper(substr($user['username'], 0, 1)); ?>
                                </div>
                                <?php endif; ?>
                                <button type="button" class="change-picture-btn" data-bs-toggle="modal" data-bs-target="#changePictureModal">
                                    <i class="fa fa-camera"></i>
                                </button>
                            </div>
                        </div>
                        <div class="col-md-10">
                            <div class="profile-info">
                                <h3 class="profile-name"><?php echo $user['full_name'] ? $user['full_name'] : $user['username']; ?></h3>
                                <p class="profile-username">@<?php echo $user['username']; ?></p>
                                <div class="profile-meta">
                                    <div class="profile-meta-item">
                                        <i class="fa fa-envelope"></i> <?php echo $user['email']; ?>
                                    </div>
                                    <?php if (!empty($user['phone'])): ?>
                                    <div class="profile-meta-item">
                                        <i class="fa fa-phone"></i> <?php echo $user['phone']; ?>
                                    </div>
                                    <?php endif; ?>
                                    <div class="profile-meta-item">
                                        <i class="fa fa-calendar"></i> Bergabung <?php echo date('d M Y', strtotime($user['created_at'])); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Profile Tabs -->
            <div class="modern-card slide-up">
                <div class="modern-card-body">
                    <ul class="nav nav-tabs" id="profileTabs" role="tablist">
                        <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="profile-tab" data-bs-toggle="tab" data-bs-target="#profile" type="button" role="tab" aria-controls="profile" aria-selected="true">
                                <i class="fa fa-user me-2"></i>Informasi Profil
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="password-tab" data-bs-toggle="tab" data-bs-target="#password" type="button" role="tab" aria-controls="password" aria-selected="false">
                                <i class="fa fa-lock me-2"></i>Ubah Password
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="address-tab" data-bs-toggle="tab" data-bs-target="#address" type="button" role="tab" aria-controls="address" aria-selected="false">
                                <i class="fa fa-map-marker-alt me-2"></i>Alamat
                            </button>
                        </li>
                    </ul>
                    
                    <div class="tab-content mt-4" id="profileTabsContent">
                        <!-- Profile Information Tab -->
                        <div class="tab-pane fade show active" id="profile" role="tabpanel" aria-labelledby="profile-tab">
                            <form method="post" action="" id="profileForm">
                                <input type="hidden" name="update_profile" value="1">
                                
                                <div class="row mb-3">
                                    <div class="col-md-6">
                                        <label for="username" class="form-label">Username</label>
                                        <input type="text" class="form-control" id="username" value="<?php echo $user['username']; ?>" disabled>
                                        <small class="text-muted">Username tidak dapat diubah.</small>
                                    </div>
                                    <div class="col-md-6">
                                        <label for="full_name" class="form-label">Nama Lengkap</label>
                                        <input type="text" class="form-control" id="full_name" name="full_name" value="<?php echo $user['full_name']; ?>">
                                    </div>
                                </div>
                                
                                <div class="row mb-3">
                                    <div class="col-md-6">
                                        <label for="email" class="form-label">Email</label>
                                        <input type="email" class="form-control" id="email" name="email" value="<?php echo $user['email']; ?>" required>
                                    </div>
                                    <div class="col-md-6">
                                        <label for="phone" class="form-label">Nomor Telepon</label>
                                        <input type="text" class="form-control" id="phone" name="phone" value="<?php echo $user['phone']; ?>">
                                    </div>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="bio" class="form-label">Bio</label>
                                    <textarea class="form-control" id="bio" name="bio" rows="4"><?php echo $user['bio']; ?></textarea>
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="modern-button modern-button-primary">
                                        <i class="fa fa-save me-2"></i>Simpan Perubahan
                                    </button>
                                </div>
                            </form>
                        </div>
                        
                        <!-- Change Password Tab -->
                        <div class="tab-pane fade" id="password" role="tabpanel" aria-labelledby="password-tab">
                            <form method="post" action="" id="passwordForm">
                                <input type="hidden" name="update_password" value="1">
                                
                                <div class="mb-3">
                                    <label for="current_password" class="form-label">Password Saat Ini</label>
                                    <input type="password" class="form-control" id="current_password" name="current_password" required>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="new_password" class="form-label">Password Baru</label>
                                    <input type="password" class="form-control" id="new_password" name="new_password" required>
                                    <small class="text-muted">Password minimal 8 karakter.</small>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="confirm_password" class="form-label">Konfirmasi Password Baru</label>
                                    <input type="password" class="form-control" id="confirm_password" name="confirm_password" required>
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="modern-button modern-button-primary">
                                        <i class="fa fa-lock me-2"></i>Ubah Password
                                    </button>
                                </div>
                            </form>
                        </div>
                        
                        <!-- Address Tab -->
                        <div class="tab-pane fade" id="address" role="tabpanel" aria-labelledby="address-tab">
                            <?php
                            // Get user addresses
                            $addresses = [];
                            try {
                                $addresses_sql = "SELECT * FROM user_addresses WHERE user_id = ? ORDER BY is_default DESC, created_at DESC";
                                $addresses_stmt = $conn->prepare($addresses_sql);
                                $addresses_stmt->bind_param("i", $user_id);
                                $addresses_stmt->execute();
                                $addresses_result = $addresses_stmt->get_result();
                                
                                while ($row = $addresses_result->fetch_assoc()) {
                                    $addresses[] = $row;
                                }
                            } catch (Throwable $e) {
                                // Handle error silently
                            }
                            ?>
                            
                            <div class="d-flex justify-content-between align-items-center mb-4">
                                <h5>Alamat Pengiriman</h5>
                                <a href="shipping-address.php" class="modern-button modern-button-primary modern-button-sm">
                                    <i class="fa fa-plus me-2"></i>Kelola Alamat
                                </a>
                            </div>
                            
                            <?php if (empty($addresses)): ?>
                            <div class="text-center py-4">
                                <div class="empty-state">
                                    <i class="fa fa-map-marker-alt fa-4x text-muted mb-3"></i>
                                    <h5>Belum Ada Alamat</h5>
                                    <p class="text-muted">Anda belum menambahkan alamat pengiriman.</p>
                                    <a href="shipping-address.php" class="modern-button modern-button-primary mt-3">
                                        <i class="fa fa-plus me-2"></i>Tambah Alamat
                                    </a>
                                </div>
                            </div>
                            <?php else: ?>
                            <div class="row">
                                <?php foreach ($addresses as $address): ?>
                                <div class="col-md-6 mb-4">
                                    <div class="modern-card address-card h-100 <?php echo $address['is_default'] ? 'address-card-default' : ''; ?>">
                                        <?php if ($address['is_default']): ?>
                                        <div class="default-badge">
                                            <i class="fa fa-check-circle me-1"></i> Utama
                                        </div>
                                        <?php endif; ?>
                                        
                                        <div class="modern-card-body">
                                            <div class="d-flex justify-content-between align-items-start mb-3">
                                                <div>
                                                    <h5 class="address-name"><?php echo htmlspecialchars($address['recipient_name']); ?></h5>
                                                    <p class="address-phone mb-0"><?php echo htmlspecialchars($address['phone']); ?></p>
                                                </div>
                                                <span class="address-type-badge <?php echo $address['address_type']; ?>">
                                                    <?php 
                                                    switch($address['address_type']) {
                                                        case 'home':
                                                            echo '<i class="fa fa-home me-1"></i> Rumah';
                                                            break;
                                                        case 'office':
                                                            echo '<i class="fa fa-building me-1"></i> Kantor';
                                                            break;
                                                        default:
                                                            echo '<i class="fa fa-map-marker-alt me-1"></i> ' . htmlspecialchars($address['address_label']);
                                                    }
                                                    ?>
                                                </span>
                                            </div>
                                            
                                            <div class="address-details">
                                                <p class="mb-1"><?php echo htmlspecialchars($address['full_address']); ?></p>
                                                <p class="mb-1">
                                                    <?php 
                                                    echo htmlspecialchars($address['district'] ? $address['district'] . ', ' : '');
                                                    echo htmlspecialchars($address['city'] . ', ' . $address['province']); 
                                                    ?>
                                                </p>
                                                <?php if (!empty($address['postal_code'])): ?>
                                                <p class="mb-0"><?php echo htmlspecialchars($address['postal_code']); ?></p>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php endforeach; ?>
                            </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Change Profile Picture Modal -->
<div class="modal fade" id="changePictureModal" tabindex="-1" aria-labelledby="changePictureModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="changePictureModalLabel">Ubah Foto Profil</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form method="post" action="" enctype="multipart/form-data" id="pictureForm">
                    <input type="hidden" name="update_picture" value="1">
                    
                    <div class="text-center mb-4">
                        <div class="profile-picture-preview">
                            <?php if (!empty($user['profile_image'])): ?>
                            <img src="<?php echo $user['profile_image']; ?>" alt="<?php echo $user['username']; ?>" id="picturePreview">
                            <?php else: ?>
                            <div class="profile-picture-placeholder" id="picturePlaceholder">
                                <?php echo strtoupper(substr($user['username'], 0, 1)); ?>
                            </div>
                            <img src="" alt="Preview" id="picturePreview" style="display: none;">
                            <?php endif; ?>
                        </div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="profile_picture" class="form-label">Pilih Foto</label>
                        <input type="file" class="form-control" id="profile_picture" name="profile_picture" accept="image/*" required>
                        <small class="text-muted">Format yang didukung: JPG, JPEG, PNG, GIF. Ukuran maksimal: 2MB.</small>
                    </div>
                    
                    <div class="text-end">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Batal</button>
                        <button type="submit" class="btn btn-primary">Simpan</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<style>
/* Profile Header */
.profile-header {
    border-radius: 12px;
    overflow: hidden;
}

.profile-picture-container {
    position: relative;
    width: 100px;
    height: 100px;
    margin: 0 auto;
}

.profile-picture {
    width: 100%;
    height: 100%;
    object-fit: cover;
    border-radius: 50%;
    border: 3px solid var(--primary);
}

.profile-picture-placeholder {
    width: 100%;
    height: 100%;
    border-radius: 50%;
    background-color: var(--primary);
    color: white;
    font-size: 2.5rem;
    display: flex;
    align-items: center;
    justify-content: center;
    border: 3px solid var(--primary);
}

.change-picture-btn {
    position: absolute;
    bottom: 0;
    right: 0;
    width: 32px;
    height: 32px;
    border-radius: 50%;
    background-color: var(--primary);
    color: white;
    border: none;
    display: flex;
    align-items: center;
    justify-content: center;
    cursor: pointer;
    transition: all 0.3s ease;
}

.change-picture-btn:hover {
    background-color: #3a5bc0;
}

.profile-info {
    padding-left: 20px;
}

.profile-name {
    font-size: 1.5rem;
    font-weight: 600;
    margin-bottom: 5px;
}

.profile-username {
    color: var(--secondary);
    margin-bottom: 10px;
}

.profile-meta {
    display: flex;
    flex-wrap: wrap;
    gap: 15px;
}

.profile-meta-item {
    color: var(--secondary);
    font-size: 0.9rem;
}

.profile-meta-item i {
    margin-right: 5px;
    color: var(--primary);
}

/* Profile Picture Preview */
.profile-picture-preview {
    width: 150px;
    height: 150px;
    margin: 0 auto;
    position: relative;
}

.profile-picture-preview img {
    width: 100%;
    height: 100%;
    object-fit: cover;
    border-radius: 50%;
    border: 3px solid var(--primary);
}

/* Address Card */
.address-card {
    position: relative;
    transition: all 0.3s ease;
    border: 1px solid #dee2e6;
}

.address-card:hover {
    transform: translateY(-5px);
    box-shadow: 0 10px 20px rgba(0,0,0,0.1);
}

.address-card-default {
    border: 2px solid var(--success);
}

.default-badge {
    position: absolute;
    top: 10px;
    right: 10px;
    background-color: var(--success);
    color: white;
    padding: 3px 10px;
    border-radius: 20px;
    font-size: 0.75rem;
    font-weight: 600;
}

.address-type-badge {
    padding: 3px 10px;
    border-radius: 20px;
    font-size: 0.75rem;
    font-weight: 600;
}

.address-type-badge.home {
    background-color: rgba(74, 110, 224, 0.1);
    color: var(--primary);
}

.address-type-badge.office {
    background-color: rgba(40, 167, 69, 0.1);
    color: var(--success);
}

.address-type-badge.other {
    background-color: rgba(108, 117, 125, 0.1);
    color: var(--secondary);
}

.address-name {
    font-weight: 600;
    margin-bottom: 5px;
}

.address-phone {
    color: var(--secondary);
    font-size: 0.9rem;
}

.address-details {
    margin-top: 15px;
    padding-top: 15px;
    border-top: 1px solid #eee;
    color: var(--secondary);
    font-size: 0.9rem;
}

.empty-state {
    padding: 30px;
    text-align: center;
}

.empty-state i {
    color: #ccc;
}

/* Responsive */
@media (max-width: 768px) {
    .profile-info {
        padding-left: 0;
        margin-top: 20px;
        text-align: center;
    }
    
    .profile-meta {
        justify-content: center;
    }
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Profile picture preview
    const profilePicture = document.getElementById('profile_picture');
    const picturePreview = document.getElementById('picturePreview');
    const picturePlaceholder = document.getElementById('picturePlaceholder');
    
    if (profilePicture && picturePreview) {
        profilePicture.addEventListener('change', function() {
            if (this.files && this.files[0]) {
                const reader = new FileReader();
                
                reader.onload = function(e) {
                    picturePreview.src = e.target.result;
                    picturePreview.style.display = 'block';
                    
                    if (picturePlaceholder) {
                        picturePlaceholder.style.display = 'none';
                    }
                }
                
                reader.readAsDataURL(this.files[0]);
            }
        });
    }
    
    // Form validation
    const passwordForm = document.getElementById('passwordForm');
    if (passwordForm) {
        passwordForm.addEventListener('submit', function(e) {
            const newPassword = document.getElementById('new_password').value;
            const confirmPassword = document.getElementById('confirm_password').value;
            
            if (newPassword !== confirmPassword) {
                e.preventDefault();
                alert('Password baru dan konfirmasi password tidak cocok.');
                return false;
            }
            
            if (newPassword.length < 8) {
                e.preventDefault();
                alert('Password baru minimal 8 karakter.');
                return false;
            }
            
            return true;
        });
    }
});
</script>

<?php include("includes/footer.php"); ?>