<?php
/**
 * WebSocket Server
 * LelangMobil Web App - Versi 2025
 * 
 * Run this script with: php server.php
 */

use Ratchet\Server\IoServer;
use Ratchet\Http\HttpServer;
use Ratchet\WebSocket\WsServer;
use Ratchet\MessageComponentInterface;
use Ratchet\ConnectionInterface;

require_once __DIR__ . '/../../vendor/autoload.php';
require_once __DIR__ . '/../../config/database.php';

/**
 * WebSocket Server Implementation
 */
class BidServer implements MessageComponentInterface {
    protected $clients;
    protected $users = [];
    protected $conn;
    
    public function __construct() {
        $this->clients = new \SplObjectStorage;
        $this->conn = $GLOBALS['conn'];
        echo "WebSocket server started\n";
    }
    
    /**
     * When a new connection is opened
     */
    public function onOpen(ConnectionInterface $conn) {
        $this->clients->attach($conn);
        echo "New connection! ({$conn->resourceId})\n";
    }
    
    /**
     * When a message is received
     */
    public function onMessage(ConnectionInterface $from, $msg) {
        $data = json_decode($msg, true);
        
        if (!$data || !isset($data['type'])) {
            return;
        }
        
        switch ($data['type']) {
            case 'auth':
                $this->handleAuth($from, $data);
                break;
                
            case 'bid':
                $this->handleBid($from, $data);
                break;
                
            case 'auto_bid':
                $this->handleAutoBid($from, $data);
                break;
                
            case 'pong':
                // Handle pong response
                break;
                
            default:
                echo "Unknown message type: {$data['type']}\n";
                break;
        }
    }
    
    /**
     * When a connection is closed
     */
    public function onClose(ConnectionInterface $conn) {
        $this->clients->detach($conn);
        
        // Remove user from users array
        foreach ($this->users as $userId => $userConn) {
            if ($userConn === $conn) {
                unset($this->users[$userId]);
                echo "User {$userId} disconnected\n";
                break;
            }
        }
        
        echo "Connection {$conn->resourceId} has disconnected\n";
    }
    
    /**
     * When an error occurs
     */
    public function onError(ConnectionInterface $conn, \Exception $e) {
        echo "An error has occurred: {$e->getMessage()}\n";
        $conn->close();
    }
    
    /**
     * Handle authentication
     */
    protected function handleAuth($conn, $data) {
        if (!isset($data['userId']) || !isset($data['token'])) {
            return;
        }
        
        $userId = $data['userId'];
        $token = $data['token'];
        
        // Verify token
        if ($this->verifyToken($userId, $token)) {
            $this->users[$userId] = $conn;
            echo "User {$userId} authenticated\n";
            
            // Send confirmation
            $conn->send(json_encode([
                'type' => 'auth_success',
                'message' => 'Authentication successful'
            ]));
        } else {
            echo "Authentication failed for user {$userId}\n";
            
            // Send error
            $conn->send(json_encode([
                'type' => 'auth_error',
                'message' => 'Authentication failed'
            ]));
        }
    }
    
    /**
     * Handle bid
     */
    protected function handleBid($conn, $data) {
        if (!isset($data['userId']) || !isset($data['vehicleId']) || !isset($data['amount'])) {
            return;
        }
        
        $userId = $data['userId'];
        $vehicleId = $data['vehicleId'];
        $amount = $data['amount'];
        
        // Check if user is authenticated
        if (!isset($this->users[$userId]) || $this->users[$userId] !== $conn) {
            $conn->send(json_encode([
                'type' => 'error',
                'message' => 'Not authenticated'
            ]));
            return;
        }
        
        // Process bid
        $result = $this->processBid($userId, $vehicleId, $amount);
        
        // Send result to user
        $conn->send(json_encode([
            'type' => 'bid_result',
            'success' => $result['success'],
            'message' => $result['message']
        ]));
        
        // If bid successful, broadcast to all users
        if ($result['success']) {
            $this->broadcastBidUpdate($vehicleId, $userId, $amount);
        }
    }
    
    /**
     * Handle auto bid
     */
    protected function handleAutoBid($conn, $data) {
        if (!isset($data['userId']) || !isset($data['vehicleId']) || !isset($data['maxAmount']) || !isset($data['increment'])) {
            return;
        }
        
        $userId = $data['userId'];
        $vehicleId = $data['vehicleId'];
        $maxAmount = $data['maxAmount'];
        $increment = $data['increment'];
        
        // Check if user is authenticated
        if (!isset($this->users[$userId]) || $this->users[$userId] !== $conn) {
            $conn->send(json_encode([
                'type' => 'error',
                'message' => 'Not authenticated'
            ]));
            return;
        }
        
        // Process auto bid
        $result = $this->processAutoBid($userId, $vehicleId, $maxAmount, $increment);
        
        // Send result to user
        $conn->send(json_encode([
            'type' => 'auto_bid_result',
            'success' => $result['success'],
            'message' => $result['message']
        ]));
    }
    
    /**
     * Broadcast bid update to all users
     */
    protected function broadcastBidUpdate($vehicleId, $bidderId, $amount) {
        // Get vehicle and bidder info
        $vehicle = $this->getVehicleInfo($vehicleId);
        $bidder = $this->getUserInfo($bidderId);
        
        if (!$vehicle || !$bidder) {
            return;
        }
        
        // Create message
        $message = [
            'type' => 'bid_update',
            'data' => [
                'vehicle_id' => $vehicleId,
                'bidder_id' => $bidderId,
                'bidder_name' => $bidder['username'],
                'bid_amount' => $amount,
                'bid_count' => $this->getBidCount($vehicleId),
                'end_time' => $vehicle['end_date']
            ]
        ];
        
        // Broadcast to all clients
        foreach ($this->clients as $client) {
            $client->send(json_encode($message));
        }
        
        // Send notification to vehicle owner
        $this->sendNotificationToOwner($vehicle['seller_id'], $vehicleId, $bidderId, $amount);
    }
    
    /**
     * Send notification to vehicle owner
     */
    protected function sendNotificationToOwner($ownerId, $vehicleId, $bidderId, $amount) {
        if ($ownerId == $bidderId) {
            return; // Don't notify if bidder is owner
        }
        
        $vehicle = $this->getVehicleInfo($vehicleId);
        $bidder = $this->getUserInfo($bidderId);
        
        if (!$vehicle || !$bidder) {
            return;
        }
        
        // Create notification
        $title = "Bid Baru";
        $message = "Bid baru sebesar Rp" . number_format($amount, 0, ',', '.') . " oleh " . $bidder['username'] . " untuk " . $vehicle['brand'] . " " . $vehicle['model'];
        
        // Insert notification to database
        $this->insertNotification($ownerId, 'bid', $title, $message, "vehicle.php?id={$vehicleId}");
        
        // Send notification to owner if online
        if (isset($this->users[$ownerId])) {
            $this->users[$ownerId]->send(json_encode([
                'type' => 'notification',
                'data' => [
                    'title' => $title,
                    'message' => $message,
                    'url' => "vehicle.php?id={$vehicleId}"
                ]
            ]));
        }
    }
    
    /**
     * Process bid
     */
    protected function processBid($userId, $vehicleId, $amount) {
        try {
            // Check if vehicle exists and is active
            $vehicle = $this->getVehicleInfo($vehicleId);
            
            if (!$vehicle) {
                return [
                    'success' => false,
                    'message' => 'Kendaraan tidak ditemukan'
                ];
            }
            
            if ($vehicle['status'] !== 'active') {
                return [
                    'success' => false,
                    'message' => 'Lelang tidak aktif'
                ];
            }
            
            // Check if bid amount is valid
            $minBid = $vehicle['current_bid'] > 0 ? $vehicle['current_bid'] * 1.05 : $vehicle['starting_price'];
            
            if ($amount < $minBid) {
                return [
                    'success' => false,
                    'message' => 'Jumlah bid terlalu rendah'
                ];
            }
            
            // Check if user has enough balance
            $user = $this->getUserInfo($userId);
            
            if (!$user) {
                return [
                    'success' => false,
                    'message' => 'User tidak ditemukan'
                ];
            }
            
            if ($user['balance'] < $amount) {
                return [
                    'success' => false,
                    'message' => 'Saldo tidak mencukupi'
                ];
            }
            
            // Insert bid
            $sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, bid_time) 
                    VALUES (?, ?, ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("iid", $vehicleId, $userId, $amount);
            $stmt->execute();
            
            // Update vehicle current bid
            $sql = "UPDATE vehicles 
                    SET current_bid = ?, current_bidder = ? 
                    WHERE vehicle_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("dii", $amount, $userId, $vehicleId);
            $stmt->execute();
            
            // Hold user balance
            $this->holdUserBalance($userId, $amount, $vehicleId);
            
            // Release previous bidder's balance if exists
            if ($vehicle['current_bidder'] && $vehicle['current_bidder'] != $userId) {
                $this->releaseUserBalance($vehicle['current_bidder'], $vehicle['current_bid'], $vehicleId);
            }
            
            return [
                'success' => true,
                'message' => 'Bid berhasil'
            ];
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => 'Error: ' . $e->getMessage()
            ];
        }
    }
    
    /**
     * Process auto bid
     */
    protected function processAutoBid($userId, $vehicleId, $maxAmount, $increment) {
        try {
            // Check if vehicle exists and is active
            $vehicle = $this->getVehicleInfo($vehicleId);
            
            if (!$vehicle) {
                return [
                    'success' => false,
                    'message' => 'Kendaraan tidak ditemukan'
                ];
            }
            
            if ($vehicle['status'] !== 'active') {
                return [
                    'success' => false,
                    'message' => 'Lelang tidak aktif'
                ];
            }
            
            // Check if max amount is valid
            $minBid = $vehicle['current_bid'] > 0 ? $vehicle['current_bid'] * 1.05 : $vehicle['starting_price'];
            
            if ($maxAmount < $minBid) {
                return [
                    'success' => false,
                    'message' => 'Jumlah maksimal bid terlalu rendah'
                ];
            }
            
            // Check if user has enough balance
            $user = $this->getUserInfo($userId);
            
            if (!$user) {
                return [
                    'success' => false,
                    'message' => 'User tidak ditemukan'
                ];
            }
            
            if ($user['balance'] < $maxAmount) {
                return [
                    'success' => false,
                    'message' => 'Saldo tidak mencukupi'
                ];
            }
            
            // Insert auto bid
            $sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, is_auto_bid, max_bid_amount, bid_increment, bid_time) 
                    VALUES (?, ?, ?, 1, ?, ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $currentBid = $vehicle['current_bid'] > 0 ? $vehicle['current_bid'] + $increment : $vehicle['starting_price'];
            $stmt->bind_param("iiddd", $vehicleId, $userId, $currentBid, $maxAmount, $increment);
            $stmt->execute();
            
            // Update vehicle current bid
            $sql = "UPDATE vehicles 
                    SET current_bid = ?, current_bidder = ? 
                    WHERE vehicle_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("dii", $currentBid, $userId, $vehicleId);
            $stmt->execute();
            
            // Hold user balance
            $this->holdUserBalance($userId, $maxAmount, $vehicleId);
            
            // Release previous bidder's balance if exists
            if ($vehicle['current_bidder'] && $vehicle['current_bidder'] != $userId) {
                $this->releaseUserBalance($vehicle['current_bidder'], $vehicle['current_bid'], $vehicleId);
            }
            
            return [
                'success' => true,
                'message' => 'Auto bid berhasil diatur'
            ];
        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => 'Error: ' . $e->getMessage()
            ];
        }
    }
    
    /**
     * Hold user balance
     */
    protected function holdUserBalance($userId, $amount, $vehicleId) {
        try {
            // Insert transaction
            $sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, created_at) 
                    VALUES (?, ?, 'bid_hold', 'completed', ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $reference = "BID-" . $vehicleId . "-" . time();
            $stmt->bind_param("ids", $userId, $amount, $reference);
            $stmt->execute();
            
            // Update user balance
            $sql = "UPDATE users 
                    SET balance = balance - ?, pending_balance = pending_balance + ? 
                    WHERE user_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("ddi", $amount, $amount, $userId);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            echo "Error holding balance: " . $e->getMessage() . "\n";
            return false;
        }
    }
    
    /**
     * Release user balance
     */
    protected function releaseUserBalance($userId, $amount, $vehicleId) {
        try {
            // Insert transaction
            $sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, created_at) 
                    VALUES (?, ?, 'bid_release', 'completed', ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $reference = "RELEASE-" . $vehicleId . "-" . time();
            $stmt->bind_param("ids", $userId, $amount, $reference);
            $stmt->execute();
            
            // Update user balance
            $sql = "UPDATE users 
                    SET balance = balance + ?, pending_balance = pending_balance - ? 
                    WHERE user_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("ddi", $amount, $amount, $userId);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            echo "Error releasing balance: " . $e->getMessage() . "\n";
            return false;
        }
    }
    
    /**
     * Insert notification
     */
    protected function insertNotification($userId, $type, $title, $message, $url = null) {
        try {
            $sql = "INSERT INTO notifications (user_id, type, title, message, url, is_read, created_at) 
                    VALUES (?, ?, ?, ?, ?, 0, NOW())";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("issss", $userId, $type, $title, $message, $url);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            echo "Error inserting notification: " . $e->getMessage() . "\n";
            return false;
        }
    }
    
    /**
     * Get vehicle info
     */
    protected function getVehicleInfo($vehicleId) {
        try {
            $sql = "SELECT v.*, 
                    COALESCE(v.brand, v.make) as brand, 
                    COALESCE(v.current_bid, v.current_price) as current_bid, 
                    COALESCE(v.starting_price, v.start_price) as starting_price, 
                    COALESCE(v.end_date, v.auction_end) as end_date 
                    FROM vehicles v 
                    WHERE v.vehicle_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("i", $vehicleId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                return $result->fetch_assoc();
            }
            
            return null;
        } catch (Exception $e) {
            echo "Error getting vehicle info: " . $e->getMessage() . "\n";
            return null;
        }
    }
    
    /**
     * Get user info
     */
    protected function getUserInfo($userId) {
        try {
            $sql = "SELECT * FROM users WHERE user_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("i", $userId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                return $result->fetch_assoc();
            }
            
            return null;
        } catch (Exception $e) {
            echo "Error getting user info: " . $e->getMessage() . "\n";
            return null;
        }
    }
    
    /**
     * Get bid count
     */
    protected function getBidCount($vehicleId) {
        try {
            $sql = "SELECT COUNT(*) as count FROM bids WHERE vehicle_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("i", $vehicleId);
            $stmt->execute();
            $result = $stmt->get_result();
            $row = $result->fetch_assoc();
            
            return $row['count'];
        } catch (Exception $e) {
            echo "Error getting bid count: " . $e->getMessage() . "\n";
            return 0;
        }
    }
    
    /**
     * Verify token
     */
    protected function verifyToken($userId, $token) {
        try {
            $sql = "SELECT * FROM users WHERE user_id = ? AND remember_token = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("is", $userId, $token);
            $stmt->execute();
            $result = $stmt->get_result();
            
            return $result->num_rows > 0;
        } catch (Exception $e) {
            echo "Error verifying token: " . $e->getMessage() . "\n";
            return false;
        }
    }
}

// Run the server
$server = IoServer::factory(
    new HttpServer(
        new WsServer(
            new BidServer()
        )
    ),
    8080
);

$server->run();