<?php
/**
 * Auto Bid Worker
 * LelangMobil Web App - Versi 2025
 */

class AutoBidWorker {
    private $conn;
    private $lastRun;
    
    public function __construct($conn) {
        $this->conn = $conn;
        $this->lastRun = time();
    }
    
    /**
     * Run the worker
     */
    public function run() {
        // Only run every 5 seconds
        if (time() - $this->lastRun < 5) {
            return;
        }
        
        $this->lastRun = time();
        $this->processAutoBids();
    }
    
    /**
     * Process auto bids
     */
    private function processAutoBids() {
        try {
            // Get active auctions
            $sql = "SELECT * FROM vehicles 
                    WHERE status = 'active' 
                    AND ((end_date IS NOT NULL AND end_date > NOW()) 
                        OR (auction_end IS NOT NULL AND auction_end > NOW()))";
            $result = $this->conn->query($sql);
            
            if ($result->num_rows > 0) {
                while ($auction = $result->fetch_assoc()) {
                    $this->processAuctionAutoBids($auction);
                }
            }
        } catch (Exception $e) {
            $this->log("Error processing auto bids: " . $e->getMessage());
        }
    }
    
    /**
     * Process auto bids for an auction
     */
    private function processAuctionAutoBids($auction) {
        $vehicleId = $auction['vehicle_id'];
        $currentBid = $auction['current_bid'] ?? $auction['current_price'] ?? 0;
        $currentBidder = $auction['current_bidder'] ?? 0;
        
        if ($currentBid <= 0) {
            return;
        }
        
        try {
            // Get auto bids for this auction
            $sql = "SELECT * FROM bids 
                    WHERE vehicle_id = ? 
                    AND is_auto_bid = 1 
                    AND max_bid_amount > ? 
                    AND bidder_id != ? 
                    ORDER BY max_bid_amount DESC, bid_time ASC 
                    LIMIT 1";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("idi", $vehicleId, $currentBid, $currentBidder);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows > 0) {
                $autoBid = $result->fetch_assoc();
                $this->placeAutoBid($auction, $autoBid);
            }
        } catch (Exception $e) {
            $this->log("Error processing auto bids for auction #{$vehicleId}: " . $e->getMessage());
        }
    }
    
    /**
     * Place auto bid
     */
    private function placeAutoBid($auction, $autoBid) {
        $vehicleId = $auction['vehicle_id'];
        $currentBid = $auction['current_bid'] ?? $auction['current_price'] ?? 0;
        $bidderId = $autoBid['bidder_id'];
        $maxBidAmount = $autoBid['max_bid_amount'];
        $bidIncrement = $autoBid['bid_increment'] > 0 ? $autoBid['bid_increment'] : 100000;
        
        // Calculate new bid amount
        $minBidAmount = $currentBid * 1.05; // 5% increment
        $newBidAmount = $currentBid + $bidIncrement;
        
        if ($newBidAmount < $minBidAmount) {
            $newBidAmount = $minBidAmount;
        }
        
        // Make sure new bid doesn't exceed max bid
        if ($newBidAmount > $maxBidAmount) {
            $newBidAmount = $maxBidAmount;
        }
        
        // Round to nearest 1000
        $newBidAmount = round($newBidAmount / 1000) * 1000;
        
        try {
            // Check if user has enough balance
            $sql = "SELECT balance FROM users WHERE user_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("i", $bidderId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows === 0) {
                $this->log("User #{$bidderId} not found for auto bid");
                return;
            }
            
            $user = $result->fetch_assoc();
            
            if ($user['balance'] < $newBidAmount) {
                $this->log("User #{$bidderId} has insufficient balance for auto bid");
                return;
            }
            
            // Insert new bid
            $sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, is_auto_bid, max_bid_amount, bid_increment, bid_time) 
                    VALUES (?, ?, ?, 1, ?, ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("iiddd", $vehicleId, $bidderId, $newBidAmount, $maxBidAmount, $bidIncrement);
            $stmt->execute();
            
            // Update vehicle current bid
            $sql = "UPDATE vehicles 
                    SET current_bid = ?, current_bidder = ? 
                    WHERE vehicle_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("dii", $newBidAmount, $bidderId, $vehicleId);
            $stmt->execute();
            
            // Hold user balance
            $this->holdUserBalance($bidderId, $newBidAmount, $vehicleId);
            
            // Release previous bidder's balance
            $currentBidder = $auction['current_bidder'] ?? 0;
            if ($currentBidder > 0 && $currentBidder != $bidderId) {
                $this->releaseUserBalance($currentBidder, $currentBid, $vehicleId);
            }
            
            // Send notification
            $this->sendAutoBidNotification($bidderId, $vehicleId, $newBidAmount);
            
            $this->log("Auto bid placed for auction #{$vehicleId} by user #{$bidderId} - Amount: {$newBidAmount}");
        } catch (Exception $e) {
            $this->log("Error placing auto bid: " . $e->getMessage());
        }
    }
    
    /**
     * Hold user balance
     */
    private function holdUserBalance($userId, $amount, $vehicleId) {
        try {
            // Insert transaction
            $sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, created_at) 
                    VALUES (?, ?, 'bid_hold', 'completed', ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $reference = "BID-" . $vehicleId . "-" . time();
            $stmt->bind_param("ids", $userId, $amount, $reference);
            $stmt->execute();
            
            // Update user balance
            $sql = "UPDATE users 
                    SET balance = balance - ?, pending_balance = pending_balance + ? 
                    WHERE user_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("ddi", $amount, $amount, $userId);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            $this->log("Error holding balance: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * Release user balance
     */
    private function releaseUserBalance($userId, $amount, $vehicleId) {
        try {
            // Insert transaction
            $sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, created_at) 
                    VALUES (?, ?, 'bid_release', 'completed', ?, NOW())";
            $stmt = $this->conn->prepare($sql);
            $reference = "RELEASE-" . $vehicleId . "-" . time();
            $stmt->bind_param("ids", $userId, $amount, $reference);
            $stmt->execute();
            
            // Update user balance
            $sql = "UPDATE users 
                    SET balance = balance + ?, pending_balance = pending_balance - ? 
                    WHERE user_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("ddi", $amount, $amount, $userId);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            $this->log("Error releasing balance: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * Send auto bid notification
     */
    private function sendAutoBidNotification($userId, $vehicleId, $amount) {
        try {
            // Get vehicle info
            $sql = "SELECT COALESCE(brand, make) as brand, model FROM vehicles WHERE vehicle_id = ?";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("i", $vehicleId);
            $stmt->execute();
            $result = $stmt->get_result();
            
            if ($result->num_rows === 0) {
                return;
            }
            
            $vehicle = $result->fetch_assoc();
            $vehicleName = $vehicle['brand'] . ' ' . $vehicle['model'];
            
            // Insert notification
            $title = "Auto Bid Berhasil";
            $message = "Auto bid Anda untuk {$vehicleName} berhasil dengan jumlah Rp" . number_format($amount, 0, ',', '.');
            $url = "vehicle.php?id={$vehicleId}";
            
            $sql = "INSERT INTO notifications (user_id, type, title, message, url, is_read, created_at) 
                    VALUES (?, 'auto_bid', ?, ?, ?, 0, NOW())";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("isss", $userId, $title, $message, $url);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            $this->log("Error sending auto bid notification: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * Log message
     */
    private function log($message) {
        $timestamp = date('Y-m-d H:i:s');
        echo "[{$timestamp}] [AutoBidWorker] {$message}" . PHP_EOL;
    }
}