<?php
/**
 * Notification Worker
 * LelangMobil Web App - Versi 2025
 */

class NotificationWorker {
    private $conn;
    private $lastRun;
    
    public function __construct($conn) {
        $this->conn = $conn;
        $this->lastRun = time();
    }
    
    /**
     * Run the worker
     */
    public function run() {
        // Only run every 30 seconds
        if (time() - $this->lastRun < 30) {
            return;
        }
        
        $this->lastRun = time();
        $this->processNotifications();
    }
    
    /**
     * Process notifications
     */
    private function processNotifications() {
        try {
            // Process transaction notifications
            $this->processTransactionNotifications();
            
            // Process auction notifications
            $this->processAuctionNotifications();
            
            // Process system notifications
            $this->processSystemNotifications();
        } catch (Exception $e) {
            $this->log("Error processing notifications: " . $e->getMessage());
        }
    }
    
    /**
     * Process transaction notifications
     */
    private function processTransactionNotifications() {
        try {
            // Get transactions that need notifications
            $sql = "SELECT t.*, u.username 
                    FROM transactions t 
                    JOIN users u ON t.user_id = u.user_id 
                    WHERE t.notification_sent = 0 OR t.notification_sent IS NULL 
                    LIMIT 50";
            $result = $this->conn->query($sql);
            
            if ($result->num_rows > 0) {
                while ($transaction = $result->fetch_assoc()) {
                    $this->sendTransactionNotification($transaction);
                    
                    // Mark notification as sent
                    $sql = "UPDATE transactions 
                            SET notification_sent = 1 
                            WHERE transaction_id = ?";
                    $stmt = $this->conn->prepare($sql);
                    $stmt->bind_param("i", $transaction['transaction_id']);
                    $stmt->execute();
                }
            }
        } catch (Exception $e) {
            $this->log("Error processing transaction notifications: " . $e->getMessage());
        }
    }
    
    /**
     * Process auction notifications
     */
    private function processAuctionNotifications() {
        try {
            // Get auctions ending soon (within 1 hour)
            $sql = "SELECT v.*, 
                    COALESCE(v.brand, v.make) as brand, 
                    COALESCE(v.model, '') as model,
                    COALESCE(v.end_date, v.auction_end) as end_date
                    FROM vehicles v 
                    WHERE v.status = 'active' 
                    AND COALESCE(v.end_date, v.auction_end) BETWEEN NOW() AND DATE_ADD(NOW(), INTERVAL 1 HOUR) 
                    AND (v.notification_sent = 0 OR v.notification_sent IS NULL)";
            $result = $this->conn->query($sql);
            
            if ($result->num_rows > 0) {
                while ($auction = $result->fetch_assoc()) {
                    $this->sendAuctionEndingSoonNotification($auction);
                    
                    // Mark notification as sent
                    $sql = "UPDATE vehicles 
                            SET notification_sent = 1 
                            WHERE vehicle_id = ?";
                    $stmt = $this->conn->prepare($sql);
                    $stmt->bind_param("i", $auction['vehicle_id']);
                    $stmt->execute();
                }
            }
        } catch (Exception $e) {
            $this->log("Error processing auction notifications: " . $e->getMessage());
        }
    }
    
    /**
     * Process system notifications
     */
    private function processSystemNotifications() {
        try {
            // Get system notifications that need to be sent
            $sql = "SELECT * FROM system_notifications 
                    WHERE sent = 0 
                    AND send_time <= NOW() 
                    LIMIT 10";
            $result = $this->conn->query($sql);
            
            if ($result && $result->num_rows > 0) {
                while ($notification = $result->fetch_assoc()) {
                    $this->sendSystemNotification($notification);
                    
                    // Mark notification as sent
                    $sql = "UPDATE system_notifications 
                            SET sent = 1, sent_time = NOW() 
                            WHERE id = ?";
                    $stmt = $this->conn->prepare($sql);
                    $stmt->bind_param("i", $notification['id']);
                    $stmt->execute();
                }
            }
        } catch (Exception $e) {
            $this->log("Error processing system notifications: " . $e->getMessage());
        }
    }
    
    /**
     * Send transaction notification
     */
    private function sendTransactionNotification($transaction) {
        $transactionId = $transaction['transaction_id'];
        $userId = $transaction['user_id'];
        $amount = $transaction['amount'];
        $type = $transaction['type'];
        $status = $transaction['status'];
        
        // Get transaction type text
        $typeText = $this->getTransactionTypeText($type);
        
        // Get transaction status text
        $statusText = $this->getTransactionStatusText($status);
        
        // Create notification
        $title = "Transaksi {$typeText}";
        $message = "Transaksi {$typeText} sebesar Rp" . number_format($amount, 0, ',', '.') . " {$statusText}.";
        $url = "transactions-modern.php";
        
        // Insert notification
        $this->insertNotification($userId, 'transaction', $title, $message, $url);
        
        $this->log("Sent transaction notification for transaction #{$transactionId} to user #{$userId}");
    }
    
    /**
     * Send auction ending soon notification
     */
    private function sendAuctionEndingSoonNotification($auction) {
        $vehicleId = $auction['vehicle_id'];
        $vehicleName = $auction['brand'] . ' ' . $auction['model'];
        $endDate = $auction['end_date'];
        
        // Get all bidders
        $sql = "SELECT DISTINCT bidder_id FROM bids WHERE vehicle_id = ?";
        $stmt = $this->conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            $bidderId = $row['bidder_id'];
            
            // Create notification
            $title = "Lelang Akan Berakhir";
            $message = "Lelang untuk {$vehicleName} akan berakhir pada " . date('d M Y H:i', strtotime($endDate)) . ".";
            $url = "vehicle.php?id={$vehicleId}";
            
            // Insert notification
            $this->insertNotification($bidderId, 'auction', $title, $message, $url);
        }
        
        $this->log("Sent ending soon notifications for auction #{$vehicleId}");
    }
    
    /**
     * Send system notification
     */
    private function sendSystemNotification($notification) {
        $notificationId = $notification['id'];
        $title = $notification['title'];
        $message = $notification['message'];
        $url = $notification['url'];
        $userType = $notification['user_type'];
        
        if ($userType === 'all') {
            // Send to all users
            $sql = "SELECT user_id FROM users WHERE is_verified = 1";
            $result = $this->conn->query($sql);
            
            while ($row = $result->fetch_assoc()) {
                $userId = $row['user_id'];
                $this->insertNotification($userId, 'system', $title, $message, $url);
            }
            
            $this->log("Sent system notification #{$notificationId} to all users");
        } elseif ($userType === 'admin') {
            // Send to admins
            $sql = "SELECT user_id FROM users WHERE is_admin = 1";
            $result = $this->conn->query($sql);
            
            while ($row = $result->fetch_assoc()) {
                $userId = $row['user_id'];
                $this->insertNotification($userId, 'system', $title, $message, $url);
            }
            
            $this->log("Sent system notification #{$notificationId} to admins");
        } elseif ($userType === 'specific') {
            // Send to specific users
            $userIds = json_decode($notification['user_ids'], true);
            
            if (is_array($userIds)) {
                foreach ($userIds as $userId) {
                    $this->insertNotification($userId, 'system', $title, $message, $url);
                }
                
                $this->log("Sent system notification #{$notificationId} to specific users");
            }
        }
    }
    
    /**
     * Insert notification
     */
    private function insertNotification($userId, $type, $title, $message, $url = null) {
        try {
            $sql = "INSERT INTO notifications (user_id, type, title, message, url, is_read, created_at) 
                    VALUES (?, ?, ?, ?, ?, 0, NOW())";
            $stmt = $this->conn->prepare($sql);
            $stmt->bind_param("issss", $userId, $type, $title, $message, $url);
            $stmt->execute();
            
            return true;
        } catch (Exception $e) {
            $this->log("Error inserting notification: " . $e->getMessage());
            return false;
        }
    }
    
    /**
     * Get transaction type text
     */
    private function getTransactionTypeText($type) {
        $types = [
            'deposit' => 'Top Up',
            'withdrawal' => 'Penarikan',
            'bid_hold' => 'Hold Bid',
            'bid_release' => 'Release Bid',
            'bid_win' => 'Menang Lelang'
        ];
        
        return $types[$type] ?? $type;
    }
    
    /**
     * Get transaction status text
     */
    private function getTransactionStatusText($status) {
        $statuses = [
            'pending' => 'menunggu',
            'verification' => 'dalam verifikasi',
            'completed' => 'selesai',
            'rejected' => 'ditolak',
            'cancelled' => 'dibatalkan'
        ];
        
        return $statuses[$status] ?? $status;
    }
    
    /**
     * Log message
     */
    private function log($message) {
        $timestamp = date('Y-m-d H:i:s');
        echo "[{$timestamp}] [NotificationWorker] {$message}" . PHP_EOL;
    }
}